@@ -1,4 +1,4 @@
- /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
+/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
  *
  * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
  *
@@ -24,12 +24,17 @@
 #include <QDBusConnection>
 #include <QDBusError>
 #include <QDBusReply>
-
+#include <QDBusMetaType>
+#include <QDBusMessage>
+#include <QDBusObjectPath>
 #include <QDebug>
+#include <QMessageBox>
 
 #include "SwitchButton/switchbutton.h"
 #include "ImageUtil/imageutil.h"
 #include "elipsemaskwidget.h"
+#include "passwdcheckutil.h"
+#include "loginedusers.h"
 
 /* qt会将glib里的signals成员识别为宏，所以取消该宏
  * 后面如果用到signals时，使用Q_SIGNALS代替即可
@@ -43,74 +48,81 @@ extern "C" {
 #include <gio/gio.h>
 }
 
-
 #define DEFAULTFACE "/usr/share/ukui/faces/default.png"
 #define ITEMHEIGH 52
 
-UserInfo::UserInfo()
+UserInfo::UserInfo() : mFirstLoad(true)
 {
-    ui = new Ui::UserInfo;
-    pluginWidget = new QWidget;
-    pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
-    ui->setupUi(pluginWidget);
-
-    pluginName = tr("Userinfo");
+    pluginName = tr("User Info");
     pluginType = ACCOUNT;
-    ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
-
-    //构建System dbus调度对象
-    sysdispatcher = new SystemDbusDispatcher;
-
-
-    //获取系统全部用户信息，用户Uid大于等于1000的
-    _acquireAllUsersInfo();
-
-
-    readCurrentPwdConf();
-    initComponent();
-    initAllUserStatus();
-    //设置界面用户信息
-    _refreshUserInfoUI();
-
-
-//    pwdSignalMapper = new QSignalMapper(this);
-//    faceSignalMapper = new QSignalMapper(this);
-//    typeSignalMapper = new QSignalMapper(this);
-//    delSignalMapper = new QSignalMapper(this);
-
-//    faceSize = QSize(64, 64);
-//    itemSize = QSize(230, 106); //?需要比btnsize大多少？否则显示不全
-//    btnSize = QSize(222, 92);
-
-
-//    get_all_users();
-//    ui_component_init();
-//    ui_status_init();
-
 }
 
 UserInfo::~UserInfo()
 {
-    delete ui;
-    delete autoSettings;
+    if (!mFirstLoad) {
+        delete ui;
+        delete autoSettings;
+    }
 }
 
-QString UserInfo::get_plugin_name(){
+QString UserInfo::get_plugin_name() {
     return pluginName;
 }
 
-int UserInfo::get_plugin_type(){
+int UserInfo::get_plugin_type() {
     return pluginType;
 }
 
-QWidget *UserInfo::get_plugin_ui(){
+QWidget *UserInfo::get_plugin_ui() {
+    if (mFirstLoad) {
+        mFirstLoad = false;
+
+        ui = new Ui::UserInfo;
+        pluginWidget = new QWidget;
+        pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
+        ui->setupUi(pluginWidget);
+
+        ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
+        ui->title2Label->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
+
+        // 构建System dbus调度对象
+        sysdispatcher = new SystemDbusDispatcher(this);
+
+        // 获取系统全部用户信息，用户Uid大于等于1000的
+        _acquireAllUsersInfo();
+
+        initSearchText();
+        readCurrentPwdConf();
+        initComponent();
+        initAllUserStatus();
+        // 设置界面用户信息
+        _refreshUserInfoUI();
+    }
     return pluginWidget;
 }
 
-void UserInfo::plugin_delay_control(){
+void UserInfo::plugin_delay_control() {
 
 }
 
+const QString UserInfo::name() const {
+
+    return QStringLiteral("userinfo");
+}
+
+void UserInfo::initSearchText() {
+    //~ contents_path /userinfo/Change pwd
+    ui->changePwdBtn->setText(tr("Change pwd"));
+    //~ contents_path /userinfo/Change type
+    ui->changeTypeBtn->setText(tr("Change type"));
+    //~ contents_path /userinfo/Change valid
+    ui->changeValidBtn->setText(tr("Change valid"));
+    //~ contents_path /userinfo/Login no passwd
+    ui->loginpwdLabel->setText(tr("Login no passwd"));
+    //~ contents_path /userinfo/enable autoLogin
+    ui->autologinLabel->setText(tr("enable autoLogin"));
+}
+
 QString UserInfo::_accountTypeIntToString(int type){
     QString atype;
     if (type == STANDARDUSER)
@@ -124,6 +136,12 @@ QString UserInfo::_accountTypeIntToString(int type){
 }
 
 void UserInfo::_acquireAllUsersInfo(){
+
+    mUserName = qgetenv("USER");
+    if (mUserName.isEmpty()) {
+        mUserName = qgetenv("USERNAME");
+    }
+
     QStringList objectpaths = sysdispatcher->list_cached_users();
 
     //初始化用户信息QMap
@@ -131,14 +149,35 @@ void UserInfo::_acquireAllUsersInfo(){
     //初始化管理员数目为0
     adminnum = 0;
 
+    //root
+    if (!getuid()){
+        UserInfomation root;
+        root.username = g_get_user_name();
+        root.current = true;
+        root.logined = true;
+        root.autologin = false;
+        root.uid = 0;
+        root.accounttype = ADMINISTRATOR;
+        root.iconfile = DEFAULTFACE;
+        allUserInfoMap.insert(root.username, root);
+    }
+
     for (QString objectpath : objectpaths){
         UserInfomation user;
         user = _acquireUserInfo(objectpath);
         allUserInfoMap.insert(user.username, user);
     }
 
-    //处理root登录
-
+    if (allUserInfoMap.isEmpty()) {
+        ui->currentUserFrame->setVisible(false);
+        ui->autoLoginFrame->setVisible(false);
+        ui->liveFrame->setVisible(true);
+    } else {
+        ui->currentUserFrame->setVisible(true);
+        ui->autoLoginFrame->setVisible(true);
+        ui->liveFrame->setVisible(false);
+    }
+    initUserPropertyConnection(objectpaths);
 }
 
 UserInfomation UserInfo::_acquireUserInfo(QString objpath){
@@ -158,25 +197,10 @@ UserInfomation UserInfo::_acquireUserInfo(QString objpath){
         QMap<QString, QVariant> propertyMap;
         propertyMap = reply.value();
         user.username = propertyMap.find("UserName").value().toString();
-        if (user.username == QString(g_get_user_name())){
+        if (user.username == QString(g_get_user_name())) {
             user.current = true;
             user.logined = true;
-
-            //获取当前用户免密登录属性
-            QDBusInterface *tmpSysinterface = new QDBusInterface("com.control.center.qt.systemdbus",
-                                             "/",
-                                             "com.control.center.interface",
-                                             QDBusConnection::systemBus());
-            //获取免密登录状态
-            QDBusReply<QString> noPwdres;
-            noPwdres  = tmpSysinterface ->call("getNoPwdLoginStatus");
-            //const QString &tmp=noPwdres;
-            if(!noPwdres.isValid()){
-                qDebug()<<"获取tmpSysinterface状态不合法---->"<< noPwdres.error();
-            }
-            delete tmpSysinterface;
-
-            user.noPwdLogin = noPwdres.value().contains(user.username) ? true : false;
+            user.noPwdLogin = getNoPwdStatus();
         }
         user.accounttype = propertyMap.find("AccountType").value().toInt();
         if (user.accounttype == ADMINISTRATOR)
@@ -220,6 +244,12 @@ void UserInfo::readCurrentPwdConf(){
         enablePwdQuality = true;
     }
 
+    if (PasswdCheckUtil::getCurrentPamState()){
+        enablePwdQuality = true;
+    } else {
+        enablePwdQuality = false;
+    }
+
     if (enablePwdQuality){
         int minLen;
         status = pwquality_get_int_value(pwdconf, PWQ_SETTING_MIN_LENGTH, &minLen);
@@ -311,20 +341,14 @@ void UserInfo::readCurrentPwdConf(){
 }
 
 void UserInfo::initComponent(){
-    //样式表
-//    pluginWidget->setStyleSheet("background: #ffffff;");
 
-//    ui->currentUserWidget->setStyleSheet("QWidget{background: #F4F4F4; border-top-left-radius: 6px; border-top-right-radius: 6px;}");
-//    ui->autoLoginWidget->setStyleSheet("QWidget{background: #F4F4F4; border-bottom-left-radius: 6px; border-bottom-right-radius: 6px;}");
-
-//    QString btnQss = QString("QPushButton{background: #FFFFFF; border-radius: 4px;}");
-//    ui->changePwdBtn->setStyleSheet(btnQss);
-//    ui->changeTypeBtn->setStyleSheet(btnQss);
-
-//    ui->addUserWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
-
-//    QString filename = "/etc/lightdm/lightdm.conf";
-//    autoSettings = new QSettings(filename, QSettings::IniFormat);
+    //root需要屏蔽部分功能
+    if (!getuid()){
+        ui->changeTypeBtn->setEnabled(false);
+        ui->changeGroupBtn->setEnabled(false);
+        ui->autoLoginFrame->setVisible(false);
+        ui->autoLoginFrame_2->setVisible(false);
+    }
 
     ui->listWidget->setStyleSheet("QListWidget::Item:hover{background:palette(base);}");
 
@@ -346,33 +370,38 @@ void UserInfo::initComponent(){
     addWgt->setLayout(addLyt);
 
     // 悬浮改变Widget状态
-    connect(addWgt, &HoverWidget::enterWidget, this, [=](QString mname){
+    connect(addWgt, &HoverWidget::enterWidget, this, [=](QString mname) {
+        Q_UNUSED(mname);
         QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "white", 12);
         iconLabel->setPixmap(pixgray);
         textLabel->setStyleSheet("color: palette(base);");
 
     });
     // 还原状态
-    connect(addWgt, &HoverWidget::leaveWidget, this, [=](QString mname){
+    connect(addWgt, &HoverWidget::leaveWidget, this, [=](QString mname) {
+        Q_UNUSED(mname);
         QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "black", 12);
         iconLabel->setPixmap(pixgray);
         textLabel->setStyleSheet("color: palette(windowText);");
     });
 
-    connect(addWgt, &HoverWidget::widgetClicked, this, [=](QString mname){
+    connect(addWgt, &HoverWidget::widgetClicked, this, [=](QString mname) {
+        Q_UNUSED(mname);
         showCreateUserDialog();
     });
 
     ui->addLyt->addWidget(addWgt);
 
-    nopwdSwitchBtn = new SwitchButton(ui->nopwdLoginFrame);
+    ui->nopwdHorLayout->setSpacing(0);
+    ui->nopwdHorLayout->setMargin(0);
+    nopwdSwitchBtn = new SwitchButton(ui->nopwdLoginWidget);
     ui->nopwdHorLayout->addWidget(nopwdSwitchBtn);
 
     autoLoginSwitchBtn = new SwitchButton(ui->autoLoginFrame);
     ui->autoLoginHorLayout->addWidget(autoLoginSwitchBtn);
 
 
-//    ui->listWidget->setStyleSheet("QListWidget{border: none}");
+//    ui->listWidget->setStyleSheet("QListWidget{background: #00ffff}");
 //    ui->listWidget->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 //    ui->listWidget->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     ui->listWidget->setSpacing(0);
@@ -385,7 +414,8 @@ void UserInfo::initComponent(){
 //    ui->addBtn->setIconSize(ui->addBtn->size());
 //    ui->addBtn->setStyleSheet("QPushButton{background-color:transparent;}");
 
-    ui->currentUserFaceLabel->installEventFilter(this);
+    if (getuid())
+        ui->currentUserFaceLabel->installEventFilter(this);
 //    ui->addUserFrame->installEventFilter(this);
 
     //修改当前用户密码的回调
@@ -397,12 +427,13 @@ void UserInfo::initComponent(){
     });
 
     //修改当前用户类型的回调
-    connect(ui->changeTypeBtn, &QPushButton::clicked, this, [=](bool checked){
-        Q_UNUSED(checked)
-        UserInfomation user = allUserInfoMap.value(g_get_user_name());
+    if (getuid())
+        connect(ui->changeTypeBtn, &QPushButton::clicked, this, [=](bool checked){
+            Q_UNUSED(checked)
+            UserInfomation user = allUserInfoMap.value(g_get_user_name());
 
-        showChangeTypeDialog(user.username);
-    });
+            showChangeTypeDialog(user.username);
+        });
 
     connect(ui->changeValidBtn, &QPushButton::clicked, this, [=](bool checked){
         Q_UNUSED(checked)
@@ -412,53 +443,60 @@ void UserInfo::initComponent(){
 
     });
 
-    //修改当前用户免密登录
-    connect(nopwdSwitchBtn, &SwitchButton::checkedChanged, [=](bool checked){
-
-        UserInfomation user = allUserInfoMap.value(g_get_user_name());
-        //免密登录状态改变
-
-        QDBusInterface * tmpSysinterface = new QDBusInterface("com.control.center.qt.systemdbus",
-                                                              "/",
-                                                              "com.control.center.interface",
-                                                              QDBusConnection::systemBus());
-
-        if (!tmpSysinterface->isValid()){
-            qCritical() << "Create Client Interface Failed When execute gpasswd: " << QDBusConnection::systemBus().lastError();
-            return;
-        }
-        tmpSysinterface->call("setNoPwdLoginStatus", checked, user.username);
-
-        delete tmpSysinterface;
-
+    connect(ui->changeGroupBtn, &QPushButton::clicked, this, [=](bool checked){
+        Q_UNUSED(checked)
+        showChangeGroupDialog();
     });
 
+    //修改当前用户免密登录
+    if (getuid())
+        connect(nopwdSwitchBtn, &SwitchButton::checkedChanged, [=](bool checked){
+
+            UserInfomation user = allUserInfoMap.value(g_get_user_name());
+            //免密登录状态改变
+
+            QDBusInterface * tmpSysinterface = new QDBusInterface("com.control.center.qt.systemdbus",
+                                                                  "/",
+                                                                  "com.control.center.interface",
+                                                                  QDBusConnection::systemBus());
+
+            if (!tmpSysinterface->isValid()){
+                qCritical() << "Create Client Interface Failed When execute gpasswd: " << QDBusConnection::systemBus().lastError();
+                return;
+            }
+            tmpSysinterface->call("setNoPwdLoginStatus", checked, user.username);
+
+            delete tmpSysinterface;
+
+        });
+
     //修改当前用户自动登录
-    connect(autoLoginSwitchBtn, &SwitchButton::checkedChanged, [=](bool checked){
-        UserInfomation user = allUserInfoMap.value(g_get_user_name());
+    if (getuid())
+        connect(autoLoginSwitchBtn, &SwitchButton::checkedChanged, [=](bool checked){
+            UserInfomation user = allUserInfoMap.value(g_get_user_name());
 
 
-        UserDispatcher * userdispatcher  = new UserDispatcher(user.objpath);
+            UserDispatcher * userdispatcher  = new UserDispatcher(user.objpath);
 
 
-//        bool status = userdispatcher->get_autoLogin_status();
+            //        bool status = userdispatcher->get_autoLogin_status();
 
-        bool status = this->getAutomaticLogin(user.username);
+            bool status = this->getAutomaticLogin(user.username);
 
 
-        if ((checked != status)) {
-            if (checked) {
-                userdispatcher->change_user_autologin(user.username);
-            } else {
-                userdispatcher->change_user_autologin("");
+            if ((checked != status)) {
+                if (checked) {
+                    userdispatcher->change_user_autologin(user.username);
+                } else {
+                    userdispatcher->change_user_autologin("");
+                }
             }
-        }
 
-//        bool lstStatus = userdispatcher->get_autoLogin_status();
+            //        bool lstStatus = userdispatcher->get_autoLogin_status();
 
-//        bool lstStatus = this->getAutomaticLogin(user.username);
-//        autoLoginSwitchBtn->setChecked(lstStatus);
-    });
+            //        bool lstStatus = this->getAutomaticLogin(user.username);
+            //        autoLoginSwitchBtn->setChecked(lstStatus);
+        });
 
     //成功删除用户的回调
     connect(sysdispatcher, &SystemDbusDispatcher::deleteuserdone, this, [=](QString objPath){
@@ -479,7 +517,7 @@ void UserInfo::initComponent(){
 
 void UserInfo::_resetListWidgetHeigh(){
     //设置其他用户控件的总高度
-    ui->listWidget->setFixedHeight((allUserInfoMap.count()) * ITEMHEIGH);
+    ui->listWidget->setFixedHeight((allUserInfoMap.count()) * ITEMHEIGH - allUserInfoMap.count() * 6);
 }
 
 void UserInfo::initAllUserStatus(){
@@ -502,6 +540,54 @@ void UserInfo::initAllUserStatus(){
     }
 }
 
+QStringList UserInfo::getLoginedUsers() {
+    m_loginedUser.clear();
+    qRegisterMetaType<LoginedUsers>("LoginedUsers");
+    qDBusRegisterMetaType<LoginedUsers>();
+    QDBusInterface loginInterface("org.freedesktop.login1",
+                                  "/org/freedesktop/login1",
+                                  "org.freedesktop.login1.Manager",
+                                  QDBusConnection::systemBus());
+
+    if (loginInterface.isValid()) {
+        qDebug() << "create interface success";
+    }
+
+    QDBusMessage result = loginInterface.call("ListUsers");
+    QList<QVariant> outArgs = result.arguments();
+    QVariant first = outArgs.at(0);
+    QDBusArgument dbvFirst = first.value<QDBusArgument>();
+    QVariant vFirst = dbvFirst.asVariant();
+    const QDBusArgument &dbusArgs = vFirst.value<QDBusArgument>();
+
+    QVector<LoginedUsers> loginedUsers;
+
+    dbusArgs.beginArray();
+    while (!dbusArgs.atEnd()) {
+        LoginedUsers user;
+        dbusArgs >> user;
+        loginedUsers.push_back(user);
+    }
+    dbusArgs.endArray();
+
+    for (LoginedUsers user : loginedUsers) {
+
+        QDBusInterface userPertyInterface("org.freedesktop.login1",
+                                          user.objpath.path(),
+                                          "org.freedesktop.DBus.Properties",
+                                          QDBusConnection::systemBus());
+
+        QDBusReply<QVariant> reply = userPertyInterface.call("Get", "org.freedesktop.login1.User", "State");
+        if (reply.isValid()) {
+            QString status = reply.value().toString();
+            if ("closing" != status) {
+                m_loginedUser.append(user.userName);
+            }
+        }
+    }
+    return m_loginedUser;
+}
+
 void UserInfo::_refreshUserInfoUI(){
     QMap<QString, UserInfomation>::iterator it = allUserInfoMap.begin();
     for (; it != allUserInfoMap.end(); it++){
@@ -549,6 +635,8 @@ void UserInfo::_buildWidgetForItem(UserInfomation user){
     baseWidget->setMaximumSize(960,50);
     baseWidget->setAttribute(Qt::WA_DeleteOnClose);
 
+    //ui->currentUserFrame->setContentsMargins(16,0,16,0);
+
     QHBoxLayout * baseVerLayout = new QHBoxLayout(baseWidget);
     baseVerLayout->setSpacing(0);
     baseVerLayout->setMargin(0);
@@ -585,7 +673,10 @@ void UserInfo::_buildWidgetForItem(UserInfomation user){
     QString btnQss = QString("QPushButton{background: #ffffff; border-radius: 4px;}");
 
     QPushButton * typeBtn = new QPushButton(widget);
-    typeBtn->setFixedSize(88, 36);
+//    typeBtn->setFixedSize(88, 36);
+    typeBtn->setFixedHeight(36);
+    typeBtn->setMinimumWidth(88);
+    typeBtn->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
     typeBtn->setText(tr("Change type"));
 //    typeBtn->setStyleSheet(btnQss);
     connect(typeBtn, &QPushButton::clicked, this, [=](bool checked){
@@ -595,7 +686,10 @@ void UserInfo::_buildWidgetForItem(UserInfomation user){
     typeBtn->hide();
 
     QPushButton * pwdBtn = new QPushButton(widget);
-    pwdBtn->setFixedSize(88, 36);
+//    pwdBtn->setFixedSize(88, 36);
+    pwdBtn->setFixedHeight(36);
+    pwdBtn->setMinimumWidth(88);
+    pwdBtn->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed);
     pwdBtn->setText(tr("Change pwd"));
 //    pwdBtn->setStyleSheet(btnQss);
     connect(pwdBtn, &QPushButton::clicked, this, [=](bool checked){
@@ -624,6 +718,13 @@ void UserInfo::_buildWidgetForItem(UserInfomation user){
 
     connect(baseWidget, &HoverWidget::enterWidget, this, [=](QString name){
         Q_UNUSED(name)
+
+        //不允许删除最后一个管理员
+        if (user.accounttype > 0 && adminnum == 1){
+            delBtn->setEnabled(false);
+        } else {
+            delBtn->setEnabled(true);
+        }
         typeBtn->show();
         pwdBtn->show();
         delBtn->show();
@@ -639,14 +740,14 @@ void UserInfo::_buildWidgetForItem(UserInfomation user){
     baseHorLayout->addWidget(delBtn, Qt::AlignVCenter);
     baseHorLayout->addSpacing(4);
 
-
     baseVerLayout->addLayout(baseHorLayout);
 //    baseVerLayout->addStretch();
 
     baseWidget->setLayout(baseVerLayout);
 
     QListWidgetItem * item = new QListWidgetItem(ui->listWidget);
-    item->setSizeHint(QSize(ui->listWidget->width() - 2, ITEMHEIGH));
+//    item->setSizeHint(QSize(ui->listWidget->width() - 4, ITEMHEIGH));
+    item->setSizeHint(QSize(QSizePolicy::Expanding, ITEMHEIGH));
     item->setData(Qt::UserRole, QVariant(user.objpath));
     ui->listWidget->setItemWidget(item, baseWidget);
 
@@ -669,6 +770,15 @@ void UserInfo::showCreateUserDialog(){
     dialog->exec();
 }
 
+QStringList UserInfo::getUsersList()
+{
+    QStringList usersStringList;
+    for (QVariant tmp : allUserInfoMap.keys()){
+        usersStringList << tmp.toString();
+    }
+    return usersStringList;
+}
+
 void UserInfo::createUser(QString username, QString pwd, QString pin, int atype){
     Q_UNUSED(pin);
     sysdispatcher->create_user(username, "", atype);
@@ -698,6 +808,12 @@ void UserInfo::createUserDone(QString objpath){
 }
 
 void UserInfo::showDeleteUserDialog(QString username){
+
+    QStringList loginedusers = getLoginedUsers();
+    if (loginedusers.contains(username)) {
+        QMessageBox::warning(pluginWidget, tr("Warning"), tr("The user is logged in, please delete the user after logging out"));
+        return;
+    }
     UserInfomation user = (UserInfomation)(allUserInfoMap.find(username).value());
 
     DelUserDialog * dialog = new DelUserDialog;
@@ -716,8 +832,8 @@ void UserInfo::deleteUser(bool removefile, QString username){
     UserInfomation user = (UserInfomation)(allUserInfoMap.find(username).value());
 
     // hidden the item when click delete user button
-    QListWidgetItem *item =  otherUserItemMap.find(user.objpath).value();
-    ui->listWidget->setItemHidden(item, true);
+//    QListWidgetItem *item =  otherUserItemMap.find(user.objpath).value();
+//    ui->listWidget->setItemHidden(item, true);
 
     sysdispatcher->delete_user(user.uid, removefile);
 }
@@ -728,6 +844,34 @@ void UserInfo::delete_user_slot(bool removefile, QString username){
     sysdispatcher->delete_user(user.uid, removefile);
 }
 
+void UserInfo::pwdAndAutoChangedSlot(QString key) {
+    if ("option" == key) {
+        autoLoginSwitchBtn->setChecked(getAutomaticLogin(mUserName));
+        nopwdSwitchBtn->setChecked(getNoPwdStatus());
+    } else if( "avatar" == key) {
+        //更新所有用户信息
+        _acquireAllUsersInfo();
+
+        //更新界面显示
+        _refreshUserInfoUI();
+    }
+}
+
+void UserInfo::propertyChangedSlot(QString property, QMap<QString, QVariant> propertyMap, QStringList propertyList) {
+    Q_UNUSED(property);
+    Q_UNUSED(propertyList);
+    if (propertyMap.keys().contains("IconFile") && getuid() &&
+            propertyMap.value("UserName").toString() == mUserName) {
+        QString iconFile = propertyMap.value("IconFile").toString();
+        QPixmap iconPixmap = QPixmap(iconFile).scaled(ui->currentUserFaceLabel->size());
+        ui->currentUserFaceLabel->setPixmap(iconPixmap);
+        if (propertyMap.keys().contains("AccountType")) {
+            int type = propertyMap.value("AccountType").toInt();
+            ui->userTypeLabel->setText(_accountTypeIntToString(type));
+        }
+    }
+}
+
 void UserInfo::deleteUserDone(QString objpath){
     QListWidgetItem * item = otherUserItemMap.value(objpath);
 
@@ -737,11 +881,18 @@ void UserInfo::deleteUserDone(QString objpath){
     //更新其他用户QMap
     otherUserItemMap.remove(objpath);
 
-    //更新所有用户信息
+    //重新获取全部用户QMap
     _acquireAllUsersInfo();
 
-    //重置其他用户ListWidget高度
-    _resetListWidgetHeigh();
+    //更新界面显示
+    _refreshUserInfoUI();
+}
+
+void UserInfo::showChangeGroupDialog(){
+//    qDebug() << "当前函数 :" << __FUNCTION__ << "当前行号 :" << __LINE__ << QDateTime::currentDateTime();
+    ChangeGroupDialog * dialog = new ChangeGroupDialog();
+    dialog->exec();
+//    qDebug() << "当前函数 :" << __FUNCTION__ << "当前行号 :" << __LINE__ << QDateTime::currentDateTime();
 }
 
 void UserInfo::showChangeValidDialog(QString username){
@@ -832,26 +983,25 @@ void UserInfo::changeUserFace(QString facefile, QString username){
 
     QString cmd = QString("cp %1 /home/%2/.face").arg(facefile).arg(user.username);
 
-    QDBusReply<QString> reply =  sysinterface->call("systemRun", QVariant(cmd));
-
+    QProcess::execute(cmd);
 
     //重新获取全部用户QMap
     _acquireAllUsersInfo();
 
     //更新界面显示
     _refreshUserInfoUI();
-
-    Q_UNUSED(reply)
 }
 
 void UserInfo::showChangePwdDialog(QString username){
+
     if (allUserInfoMap.keys().contains(username)){
         UserInfomation user = allUserInfoMap.value(username);
-
-        ChangePwdDialog * dialog = new ChangePwdDialog;
+        ChangePwdDialog * dialog = new ChangePwdDialog(user.current);
         dialog->setFace(user.iconfile);
         dialog->setUsername(user.username);
         dialog->setAccountType(_accountTypeIntToString(user.accounttype));
+        if (!getuid() && user.current)
+            dialog->haveCurrentPwdEdit(false);
         connect(dialog, &ChangePwdDialog::passwd_send, this, [=](QString pwd, QString userName){
             changeUserPwd(pwd, userName);
         });
@@ -904,3 +1054,33 @@ bool UserInfo::getAutomaticLogin(QString username) {
 
     return autoUser == username ? true : false;
 }
+
+bool UserInfo::getNoPwdStatus() {
+    // 获取当前用户免密登录属性
+    QDBusInterface tmpSysinterface("com.control.center.qt.systemdbus",
+                                     "/",
+                                     "com.control.center.interface",
+                                     QDBusConnection::systemBus());
+    // 获取免密登录状态
+    QDBusReply<QString> noPwdres;
+    noPwdres  = tmpSysinterface.call("getNoPwdLoginStatus");
+    if (!noPwdres.isValid()) {
+        qDebug() << noPwdres.error();
+    }
+    return (noPwdres.value().contains(mUserName) ? true : false);
+}
+
+void UserInfo::initUserPropertyConnection(const QStringList &objPath) {
+
+    foreach (QString userPath, objPath) {
+        QDBusInterface iproperty("org.freedesktop.Accounts",
+                                 userPath,
+                                 "org.freedesktop.DBus.Properties",
+                                 QDBusConnection::systemBus());
+
+        iproperty.connection().connect("org.freedesktop.Accounts", userPath, "org.freedesktop.DBus.Properties", "PropertiesChanged",
+                                        this, SLOT(propertyChangedSlot(QString, QMap<QString, QVariant>, QStringList)));
+    }
+
+    QDBusConnection::sessionBus().connect(QString(), QString("/org/kylinssoclient/path"), "org.freedesktop.kylinssoclient.interface", "keyChanged", this, SLOT(pwdAndAutoChangedSlot(QString)));
+}
