@@ -51,16 +51,14 @@ public:
     int get_plugin_type() Q_DECL_OVERRIDE;
     QWidget *get_plugin_ui() Q_DECL_OVERRIDE;
     void plugin_delay_control() Q_DECL_OVERRIDE;
+    const QString name() const Q_DECL_OVERRIDE;
 
-public:
     void setupStylesheet();
     void setupComponent();
     void setupConnect();
     void initGeneralStatus();
     void rebuildLayoutsComBox();
-
-protected:
-//    bool eventFilter(QObject *watched, QEvent *event);
+    void setKeyboardVisible(bool checked);
 
 private:
     Ui::KeyboardControl *ui;
@@ -69,7 +67,6 @@ private:
     int pluginType;
     QWidget * pluginWidget;
 
-private:
     QGSettings * settings;
     QGSettings * kbdsettings;
     QGSettings * osdSettings;
@@ -82,8 +79,8 @@ private:
 
     HoverWidget * addWgt;
 
-private:
     bool settingsCreate;
+    bool mFirstLoad;
 };
 
 #endif // KEYBOARDCONTROL_H
