@@ -19,6 +19,7 @@
  */
 #include "addshortcutdialog.h"
 #include "ui_addshortcutdialog.h"
+#include "CloseButton/closebutton.h"
 
 #include "realizeshortcutwheel.h"
 
@@ -33,48 +34,16 @@ addShortcutDialog::addShortcutDialog(QWidget *parent) :
     ui->setupUi(this);
     setWindowFlags(Qt::FramelessWindowHint | Qt::Tool);
     setAttribute(Qt::WA_TranslucentBackground);
+    setWindowTitle(tr("Add custom shortcut"));
 
     ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
-    ui->closeBtn->setProperty("useIconHighlightEffect", true);
-    ui->closeBtn->setProperty("iconHighlightEffectMode", 1);
-    ui->closeBtn->setFlat(true);
-
-    ui->closeBtn->setStyleSheet("QPushButton:hover:!pressed#closeBtn{background: #FA6056; border-radius: 4px;}"
-                                "QPushButton:hover:pressed#closeBtn{background: #E54A50; border-radius: 4px;}");
-
-//    ui->frame->setStyleSheet("QFrame{background: #ffffff; border: none; border-radius: 6px;}");
-
-    //关闭按钮在右上角，窗体radius 6px，所以按钮只得6px
-//    ui->closeBtn->setStyleSheet("QPushButton#closeBtn{background: #ffffff; border: none; border-radius: 6px;}"
-//                                "QPushButton:hover:!pressed#closeBtn{background: #FA6056; border: none; border-top-left-radius: 2px; border-top-right-radius: 6px; border-bottom-left-radius: 2px; border-bottom-right-radius: 2px;}"
-//                                "QPushButton:hover:pressed#closeBtn{background: #E54A50; border: none; border-top-left-radius: 2px; border-top-right-radius: 6px; border-bottom-left-radius: 2px; border-bottom-right-radius: 2px;}");
-
-//    QString lineEditQss = QString("QLineEdit{background: #E9E9E9; border: none; border-radius: 4px;}");
-//    ui->nameLineEdit->setStyleSheet(lineEditQss);
-//    ui->execLineEdit->setStyleSheet(lineEditQss);
-
-//    QString btnQss = QString("QPushButton{background: #E9E9E9; border-radius: 4px;}"
-//                             "QPushButton:checked{background: #3d6be5; border-radius: 4px;}"
-//                             "QPushButton:hover:!pressed{background: #3d6be5; border-radius: 4px;}"
-//                             "QPushButton:hover:pressed{background: #415FC4; border-radius: 4px;}");
-
-//    ui->cancelBtn->setStyleSheet(btnQss);
-//    ui->certainBtn->setStyleSheet(btnQss);
-
-    ui->closeBtn->setIcon(QIcon(QPixmap("://img/titlebar/close.svg")));
     ui->noteLabel->setPixmap(QPixmap("://img/plugins/shortcut/note.png"));
-
     ui->stackedWidget->setCurrentIndex(1);
 
-
     refreshCertainChecked();
 
     gsPath = "";
 
-    connect(ui->closeBtn, &QPushButton::clicked, [=](bool checked){
-        Q_UNUSED(checked)
-        close();
-    });
     connect(ui->openBtn, &QPushButton::clicked, [=](bool checked){
         Q_UNUSED(checked)
         openProgramFileDialog();
@@ -102,7 +71,7 @@ addShortcutDialog::addShortcutDialog(QWidget *parent) :
         close();
     });
     connect(ui->certainBtn, &QPushButton::clicked, [=]{
-        emit shortcutInfoSignal(gsPath, ui->nameLineEdit->text(), ui->execLineEdit->text());
+        emit shortcutInfoSignal(gsPath, ui->nameLineEdit->text(), selectedfile);
 
         close();
     });
@@ -147,6 +116,7 @@ void addShortcutDialog::paintEvent(QPaintEvent *event) {
     pixmapPainter.setRenderHint(QPainter::Antialiasing);
     pixmapPainter.setPen(Qt::transparent);
     pixmapPainter.setBrush(Qt::black);
+    pixmapPainter.setOpacity(0.65);
 
     pixmapPainter.drawPath(rectPath);
     pixmapPainter.end();
@@ -183,12 +153,12 @@ void addShortcutDialog::openProgramFileDialog(){
     fd.setNameFilter(filters);
     fd.setFileMode(QFileDialog::ExistingFile);
     fd.setWindowTitle(tr("select desktop"));
-    fd.setLabelText(QFileDialog::Accept, "Select");
+//    fd.setLabelText(QFileDialog::Accept, "Select");
+    fd.setLabelText(QFileDialog::Reject, tr("Cancel"));
 
     if (fd.exec() != QDialog::Accepted)
         return;
 
-    QString selectedfile;
     selectedfile = fd.selectedFiles().first();
 
     QString exec = selectedfile.section("/", -1, -1);
