@@ -25,20 +25,11 @@
 #include <QPushButton>
 #include <QDebug>
 #include <QVector>
-
 #include <QGSettings>
 
 #include <shell/interface.h>
 #include "SwitchButton/switchbutton.h"
 
-
-//typedef _NoticeEntry NoticeEntry;
-//struct _NoticeEntry : QObjectUserData{
-////    int keyval;
-//    QString gsSchema;
-//    QString keyStr;
-//};
-
 /* qt会将glib里的signals成员识别为宏，所以取消该宏
  * 后面如果用到signals时，使用Q_SIGNALS代替即可
  **/
@@ -70,7 +61,9 @@ public:
     int get_plugin_type() Q_DECL_OVERRIDE;
     QWidget * get_plugin_ui() Q_DECL_OVERRIDE;
     void plugin_delay_control() Q_DECL_OVERRIDE;
+    const QString name() const  Q_DECL_OVERRIDE;
 
+    void initSearchText();
     void setupComponent();
     void setupGSettings();
     void initNoticeStatus();
@@ -97,6 +90,8 @@ private:
     QGSettings * oriSettings;
     QStringList appsName;
     QStringList appsKey;
-    QVector<QGSettings*> *vecGsettins;
+    QVector<QGSettings*> vecGsettins;
+
+    bool mFirstLoad;
 };
 #endif // NOTICE_H
