@@ -27,6 +27,15 @@
 #include <QVector>
 #include <QPushButton>
 #include <QMap>
+#include <QProcess>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QComboBox>
+#include <QtWidgets/QHBoxLayout>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QSpinBox>
+#include <QtWidgets/QVBoxLayout>
+#include <QTimer>
+#include <QFrame>
 
 #include "shell/interface.h"
 
@@ -43,7 +52,6 @@ class Desktop : public QObject, CommonInterface
     Q_PLUGIN_METADATA(IID "org.kycc.CommonInterface")
     Q_INTERFACES(CommonInterface)
 
-
 public:
     Desktop();
     ~Desktop();
@@ -52,8 +60,9 @@ public:
     int get_plugin_type() Q_DECL_OVERRIDE;
     QWidget * get_plugin_ui() Q_DECL_OVERRIDE;
     void plugin_delay_control() Q_DECL_OVERRIDE;
+    const QString name() const  Q_DECL_OVERRIDE;
 
-public:
+    void initSearchText();
     void initTranslation();
     void setupComponent();
     void setupConnect();
@@ -61,10 +70,24 @@ public:
     void initLockingStatus();
     void initTrayStatus(QString name, QIcon icon, QGSettings *gsettings);
     void initTraySettings();
-
-
+    void clearContent();
 
 private:
+    QMap<QString, QIcon> desktopConver(QString processName);
+    bool isFileExist(QString fullFileName);
+
+private:
+    Ui::Desktop *ui;
+
+    int pluginType;
+    QString pluginName;
+    QWidget * pluginWidget;
+    QVector<QGSettings*> vecGsettings;
+    QMap<QString, QString> transMap; // transaltion Map
+    QMap<QString, QString> iconMap;
+    QStringList disList;
+    QStringList nameList;
+
     SwitchButton * deskComputerSwitchBtn;
     SwitchButton * deskTrashSwitchBtn;
     SwitchButton * deskHomeSwitchBtn;
@@ -79,17 +102,43 @@ private:
 
     QGSettings * dSettings;
 
-private:
-    Ui::Desktop *ui;
+    QSharedPointer<QProcess> cmd;
 
-    int pluginType;
-    QString pluginName;
-    QWidget * pluginWidget;
-    QVector<QGSettings*> *vecGsettings;
-    QMap<QString, QString> transMap; // transaltion Map
-    QMap<QString, QString> iconMap;
-    QStringList disList;
+    bool mFirstLoad;
+    void initPanelSetUI();
+    void initPanelSetItem();
 
+    int getPanelSize();
+    int getPanelPosition();
+
+    QGSettings  *settings;
+    QHBoxLayout *hLayoutPanelSet;
+    QHBoxLayout *hLayoutPanelSizeSet;
+    QHBoxLayout *hLayoutPanelPositionSet;
+    QHBoxLayout *hLayoutQuicklaunchNumSet;
+    QLabel      *labelPanelTitle;
+    QLabel      *labelPanelSize;
+    QLabel      *labelPanelPosition;
+    QLabel      *labelQuicklaunchNum;
+    QComboBox   *comboBoxPanelSize;
+    QComboBox   *comboBoxPanelPosition;
+    QSpinBox    *spinBoxQuickLaunchNum;
+
+    QStringList mPanelGSettings;
+
+    QFrame *quicklaunchNumFrame;
+
+private slots:
+    void removeTrayItem(QString itemName);
+    void addTrayItem(QGSettings * trayGSetting);
+    QString desktopToName(QString desktopfile);
+    QIcon   desktopToIcon(const QString &desktopfile);
+    QMap<QString, QIcon> readOuputSlot();
+    void readErrorSlot();
+    void slotCloudAccout(const QString &key);
+    void panelSizeComboboxChangedSlot(int );
+    void panelPositionComboboxChangedSlot(int );
+    void quicklaunchNumSpinBoxChangedSlot(int);
 };
 
 #endif // DESKTOP_H
