@@ -20,7 +20,6 @@
 #ifndef FONTS_H
 #define FONTS_H
 
-
 #include <QObject>
 #include <QtPlugin>
 #include <QPushButton>
@@ -28,6 +27,7 @@
 #include <QFontDatabase>
 #include <QGSettings>
 #include <QStyledItemDelegate>
+#include <QtDBus>
 
 #include "shell/interface.h"
 #include "Uslider/uslider.h"
@@ -64,8 +64,10 @@ public:
     int get_plugin_type() Q_DECL_OVERRIDE;
     QWidget * get_plugin_ui() Q_DECL_OVERRIDE;
     void plugin_delay_control() Q_DECL_OVERRIDE;
+    const QString name() const  Q_DECL_OVERRIDE;
 
 public:
+    void initSearchText();
     void setupStylesheet();
     void setupComponent();
     void setupConnect();
@@ -86,6 +88,8 @@ public:
     int fontConvertToSlider(const int size) const;
     int sliderConvertToSize(const int value) const;
 
+    void connectToServer();
+
 private:
     Ui::Fonts *ui;
 
@@ -105,13 +109,16 @@ private:
     QStringList peonyfontStrList;
     QStringList titlebarfontStrList;
 
+    QDBusInterface *m_cloudInterface;
     QFontDatabase fontdb;
+public Q_SLOTS:
+    void keyChangedSlot(const QString &key);
 
 private:
     bool settingsCreate;
+    bool mFirstLoad;
     QGSettings * stylesettings;
     Uslider * uslider;
-
 };
 
 #endif // FONTS_H
