@@ -19,66 +19,71 @@
  */
 #include "screenlock.h"
 #include "ui_screenlock.h"
-
-#include <QDebug>
-#include <QDir>
-
-#define BGPATH "/usr/share/backgrounds/"
-#define SCREENLOCK_BG_SCHEMA "org.ukui.screensaver"
-#define SCREENLOCK_BG_KEY "background"
-#define SCREENLOCK_DELAY_KEY "lock-delay"
-#define SCREENLOCK_LOCK_KEY "lock-enabled"
-#define SCREENLOCK_ACTIVE_KEY "idle-activation-enabled"
-
-#define MATE_BACKGROUND_SCHEMAS "org.mate.background"
-#define FILENAME "picture-filename"
-
 #include "bgfileparse.h"
 #include "pictureunit.h"
 #include "MaskWidget/maskwidget.h"
 
-Screenlock::Screenlock()
-{
-    ui = new Ui::Screenlock;
-    pluginWidget = new QWidget;
-    pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
-    ui->setupUi(pluginWidget);
+#include <QDebug>
+#include <QDir>
 
+#define BGPATH                "/usr/share/backgrounds/"
+#define SCREENLOCK_BG_SCHEMA  "org.ukui.screensaver"
+#define SCREENLOCK_BG_KEY     "background"
+#define SCREENLOCK_DELAY_KEY  "lock-delay"
+#define SCREENLOCK_LOCK_KEY   "lock-enabled"
+#define SCREENLOCK_ACTIVE_KEY "idle-activation-enabled"
+
+#define MATE_BACKGROUND_SCHEMAS "org.mate.background"
+#define FILENAME                "picture-filename"
+
+Screenlock::Screenlock() : mFirstLoad(true)
+{
     pluginName = tr("Screenlock");
     pluginType = PERSONALIZED;
-
-    ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
-    ui->title1Label->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
-    ui->title2Label->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
-
-    const QByteArray id(SCREENLOCK_BG_SCHEMA);
-    lSetting = new QGSettings(id);
-
-
-    setupComponent();
-    setupConnect();
-    initScreenlockStatus();
-
-    lockbgSize = QSize(400, 240);
 }
 
 Screenlock::~Screenlock()
 {
-    delete ui;
-    delete lSetting;
-    delete lockSetting;
-    delete lockLoginSettings;
+    if (!mFirstLoad) {
+        delete ui;
+        delete lSetting;
+        delete lockSetting;
+        delete lockLoginSettings;
+    }
 }
 
-QString Screenlock::get_plugin_name(){
+QString Screenlock::get_plugin_name() {
     return pluginName;
 }
 
-int Screenlock::get_plugin_type(){
+int Screenlock::get_plugin_type() {
     return pluginType;
 }
 
-QWidget *Screenlock::get_plugin_ui(){
+QWidget *Screenlock::get_plugin_ui() {
+    if (mFirstLoad) {
+        mFirstLoad = false;
+
+        ui = new Ui::Screenlock;
+        pluginWidget = new QWidget;
+        pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
+        ui->setupUi(pluginWidget);
+
+        ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
+        ui->title1Label->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
+        ui->title2Label->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
+
+        const QByteArray id(SCREENLOCK_BG_SCHEMA);
+        lSetting = new QGSettings(id);
+
+        connectToServer();
+        initSearchText();
+        setupComponent();
+        setupConnect();
+        initScreenlockStatus();
+
+        lockbgSize = QSize(400, 240);
+    }
     return pluginWidget;
 }
 
@@ -86,6 +91,18 @@ void Screenlock::plugin_delay_control(){
 
 }
 
+const QString Screenlock::name() const {
+
+    return QStringLiteral("screenlock");
+}
+
+void Screenlock::initSearchText() {
+    //~ contents_path /screenlock/Show picture of screenlock on screenlogin
+    ui->loginpicLabel->setText(tr("Show picture of screenlock on screenlogin"));
+    //~ contents_path /screenlock/Lock screen when screensaver boot
+    ui->activepicLabel->setText(tr("Lock screen when screensaver boot"));
+}
+
 void Screenlock::setupComponent(){
     QString filename = QDir::homePath() + "/.config/ukui/ukui-control-center.conf";
     lockSetting = new QSettings(filename, QSettings::IniFormat);
@@ -130,13 +147,12 @@ void Screenlock::setupComponent(){
         lockSwitchBtn->setChecked(status);
     }
 
-    connect(lockSwitchBtn, &SwitchButton::checkedChanged, this, [=](bool checked){
+    connect(lockSwitchBtn, &SwitchButton::checkedChanged, this, [=](bool checked) {
         if (lockKey) {
             lSetting->set(SCREENLOCK_LOCK_KEY,  checked);
         }
     });
 
-
     connect(lSetting, &QGSettings::changed, this, [=](QString key) {
         if ("idleActivationEnabled" == key) {
             bool judge = lSetting->get(key).toBool();
@@ -161,13 +177,11 @@ void Screenlock::setupComponent(){
 }
 
 void Screenlock::setupConnect(){
-//    ui->delaySlider->setMinimum(1);
-//    ui->delaySlider->setMaximum(120);
-    connect(loginbgSwitchBtn, &SwitchButton::checkedChanged, this, [=](bool checked){
+    connect(loginbgSwitchBtn, &SwitchButton::checkedChanged, this, [=](bool checked) {
         setLockBackground(checked);
     });
 
-    connect(uslider, &QSlider::valueChanged, [&](int value){
+    connect(uslider, &QSlider::valueChanged, [&](int value) {
         QStringList keys = lSetting->keys();
         if (keys.contains("lockDelay")) {
             lSetting->set(SCREENLOCK_DELAY_KEY, convertToLocktime(value));
@@ -177,13 +191,12 @@ void Screenlock::setupConnect(){
     QStringList keys = lSetting->keys();
     if (keys.contains("lockDelay")) {
         int value = lockConvertToSlider(lSetting->get(SCREENLOCK_DELAY_KEY).toInt());
-
         uslider->setValue(value);
     }
 }
 
 void Screenlock::initScreenlockStatus(){
-    //获取当前锁屏壁纸
+    // 获取当前锁屏壁纸
     QString bgStr = lSetting->get(SCREENLOCK_BG_KEY).toString();
     if (bgStr.isEmpty()) {
         if (QGSettings::isSchemaInstalled(MATE_BACKGROUND_SCHEMAS)) {
@@ -194,20 +207,20 @@ void Screenlock::initScreenlockStatus(){
 
     ui->previewLabel->setPixmap(QPixmap(bgStr).scaled(ui->previewLabel->size()));
 
-    //遮罩
-    MaskWidget * maskWidget = new MaskWidget(ui->previewLabel);
-    maskWidget->setGeometry(0, 0, ui->previewLabel->width(), ui->previewLabel->height());
+    // 遮罩
+//    MaskWidget * maskWidget = new MaskWidget(ui->previewLabel);
+//    maskWidget->setGeometry(0, 0, ui->previewLabel->width(), ui->previewLabel->height());
 
-    //使用线程解析本地壁纸文件；获取壁纸单元
+    // 使用线程解析本地壁纸文件；获取壁纸单元
     pThread = new QThread;
     pWorker = new BuildPicUnitsWorker;
     connect(pWorker, &BuildPicUnitsWorker::pixmapGeneral, this, [=](QPixmap pixmap, BgInfo bgInfo){
-        //设置当前锁屏壁纸的预览
+        // 设置当前锁屏壁纸的预览
         if (bgInfo.filename == bgStr){
             ui->previewLabel->setPixmap(QPixmap(bgStr).scaled(ui->previewLabel->size()));
         }
 
-        //线程中构建控件传递会报告event无法install 的警告
+        // 线程中构建控件传递会报告event无法install 的警告
         PictureUnit * picUnit = new PictureUnit;
         picUnit->setPixmap(pixmap);
         picUnit->setFilenameText(bgInfo.filename);
@@ -221,23 +234,20 @@ void Screenlock::initScreenlockStatus(){
         flowLayout->addWidget(picUnit);
     });
     connect(pWorker, &BuildPicUnitsWorker::workerComplete, [=]{
-        pThread->quit(); //退出事件循环
-        pThread->wait(); //释放资源
+        pThread->quit(); // 退出事件循环
+        pThread->wait(); // 释放资源
     });
 
     pWorker->moveToThread(pThread);
     connect(pThread, &QThread::started, pWorker, &BuildPicUnitsWorker::run);
-    connect(pThread, &QThread::finished, this, [=]{
+    connect(pThread, &QThread::finished, this, [=] {
 
     });
     connect(pThread, &QThread::finished, pWorker, &BuildPicUnitsWorker::deleteLater);
 
     pThread->start();
 
-    //设置登录界面背景开关
-
-
-    //设置锁屏时间，屏保激活后多久锁定屏幕
+    // 设置锁屏时间，屏保激活后多久锁定屏幕
     int lDelay = lSetting->get(SCREENLOCK_DELAY_KEY).toInt();
 //    ui->delaySlider->blockSignals(true);
 //    ui->delaySlider->setValue(lDelay);
@@ -314,16 +324,6 @@ int Screenlock::lockConvertToSlider(const int value) {
 
 void Screenlock::setLockBackground(bool status)
 {
-    QString username;
-#if QT_VERSION <= QT_VERSION_CHECK(5,12,0)
-    username = qgetenv("USER");
-    if (username.isEmpty()) {
-        username = qgetenv("USERNAME");
-    }
-#else
-    username = "";
-#endif
-
     QString bgStr;
     if (lSetting && status) {
         bgStr= lSetting->get(SCREENLOCK_BG_KEY).toString();
@@ -331,36 +331,59 @@ void Screenlock::setLockBackground(bool status)
         bgStr = "";
     }
 
-    if (!bgStr.isEmpty()) {
-        int index = bgStr.lastIndexOf('/');
-        bgStr = bgStr.mid(index, bgStr.length() - index);
-    }
-
-    QString picname;
-
-    if (!bgStr.isEmpty()) {
-        if (!username.isEmpty()) {
-            picname = "/usr/share/backgrounds/" + username + bgStr;
-        } else {
-            picname = "/usr/share/backgrounds"  + bgStr;
-        }
-    } else {
-        picname = "";
-    }
-
     lockSetting->beginGroup("ScreenLock");
     lockSetting->setValue("lockStatus", status);
     lockSetting->endGroup();
 
     lockLoginSettings->beginGroup("greeter");
-    lockLoginSettings->setValue("backgroundPath", picname);
+    lockLoginSettings->setValue("backgroundPath", bgStr);
     lockLoginSettings->endGroup();
 }
 
 bool Screenlock::getLockStatus()
 {
     lockSetting->beginGroup("ScreenLock");
+    lockSetting->sync();
     bool status = lockSetting->value("lockStatus").toBool();
     lockSetting->endGroup();
     return  status;
 }
+
+void Screenlock::connectToServer(){
+    m_cloudInterface = new QDBusInterface("org.kylinssoclient.dbus",
+                                          "/org/kylinssoclient/path",
+                                          "org.freedesktop.kylinssoclient.interface",
+                                          QDBusConnection::sessionBus());
+    if (!m_cloudInterface->isValid())
+    {
+        qDebug() << "fail to connect to service";
+        qDebug() << qPrintable(QDBusConnection::systemBus().lastError().message());
+        return;
+    }
+//    QDBusConnection::sessionBus().connect(cloudInterface, SIGNAL(shortcutChanged()), this, SLOT(shortcutChangedSlot()));
+    QDBusConnection::sessionBus().connect(QString(), QString("/org/kylinssoclient/path"), QString("org.freedesktop.kylinssoclient.interface"), "keyChanged", this, SLOT(keyChangedSlot(QString)));
+    // 将以后所有DBus调用的超时设置为 milliseconds
+    m_cloudInterface->setTimeout(2147483647); // -1 为默认的25s超时
+}
+
+void Screenlock::keyChangedSlot(const QString &key) {
+    if(key == "ukui-screensaver") {
+        if(!bIsCloudService)
+            bIsCloudService = true;
+        QString bgStr = lSetting->get(SCREENLOCK_BG_KEY).toString();
+        if (bgStr.isEmpty()) {
+            if (QGSettings::isSchemaInstalled(MATE_BACKGROUND_SCHEMAS)) {
+                QGSettings * bgGsetting  = new QGSettings(MATE_BACKGROUND_SCHEMAS, QByteArray(), this);
+                bgStr = bgGsetting->get(FILENAME).toString();
+            }
+        }
+
+        ui->previewLabel->setPixmap(QPixmap(bgStr).scaled(ui->previewLabel->size()));
+        QStringList keys =  lSetting->keys();
+        if (keys.contains("lockEnabled")) {
+            bool status = lSetting->get(SCREENLOCK_LOCK_KEY).toBool();
+            lockSwitchBtn->setChecked(status);
+        }
+        loginbgSwitchBtn->setChecked(getLockStatus());
+    }
+}
