@@ -35,6 +35,10 @@
 #define SESSION_SCHEMA "org.ukui.session"
 #define IDLE_DELAY_KEY "idle-delay"
 
+#define BACKGROUND_SCHEMA "org.mate.background"
+
+const QString BACK_FILENAME_KEY = "pictureFilename";
+
 #define IDLEMIN 1
 #define IDLEMAX 120
 #define IDLESTEP 1
@@ -56,83 +60,76 @@ void PreviewWidget::paintEvent(QPaintEvent *e){
 }
 
 
-Screensaver::Screensaver()
+Screensaver::Screensaver() : mFirstLoad(true)
 {
-    ui = new Ui::Screensaver;
-    pluginWidget = new QWidget;
-    pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
-    ui->setupUi(pluginWidget);
-
     pluginName = tr("Screensaver");
     pluginType = PERSONALIZED;
-
-    ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
-
-//    pluginWidget->setStyleSheet("background: #ffffff;");
-
-    ui->previewWidget->setStyleSheet("#previewWidget{background: black; border-radius: 6px;}");
-    ui->previewWidget->setAutoFillBackground(true);
-
-//    mPreviewWidget = new PreviewWidget;
-//    mPreviewWidget->resize(400,222);
-//    QBoxLayout *mPreviewLayout = new QBoxLayout(QBoxLayout::TopToBottom);
-//    mPreviewLayout->addWidget(mPreviewWidget);
-//    ui->previewWidget->setLayout(mPreviewLayout);
-
-//    ui->enableWidget->setStyleSheet("QWidget{background: #F4F4F4; border-top-left-radius: 6px; border-top-right-radius: 6px;}");
-
-//    ui->programWidget->setStyleSheet("QWidget#programWidget{background: #F4F4F4;}");
-//    ui->programLabel->setStyleSheet("QLabel{background: #F4F4F4;}");
-
-//    ui->idleWidget->setStyleSheet("QWidget{background: #F4F4F4; border-bottom-left-radius: 6px; border-bottom-right-radius: 6px;}");
-//    ui->idleLineEdit->setStyleSheet("QLineEdit{background: #ffffff; border-radius: 0px;}");
-
-//    ui->lockWidget->setStyleSheet("QWidget{background: #F4F4F4; border-radius: 6px;}");
-
-    process = new QProcess();
-
-    _acquireThemeinfoList();
-    initComponent();
-    initEnableBtnStatus();
-    initThemeStatus();
-    initIdleSliderStatus();
-
-//    init_theme_info_map();
-//    component_init();
-//    status_init();
 }
 
-Screensaver::~Screensaver()
-{
-    delete ui;
-    delete process;
-    process = nullptr;    
-    if (!screenlock_settings) {
-        delete screenlock_settings;
+Screensaver::~Screensaver() {
+    if (!mFirstLoad) {
+        delete ui;
+        delete process;
+        process = nullptr;
     }
 }
 
-QString Screensaver::get_plugin_name(){
+QString Screensaver::get_plugin_name() {
     return pluginName;
 }
 
-int Screensaver::get_plugin_type(){
+int Screensaver::get_plugin_type() {
     return pluginType;
 }
 
-QWidget *Screensaver::get_plugin_ui(){
+QWidget *Screensaver::get_plugin_ui() {
+    if (mFirstLoad) {
+        mFirstLoad = false;
+
+        ui = new Ui::Screensaver;
+        pluginWidget = new QWidget;
+        pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
+        ui->setupUi(pluginWidget);
+        ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
+
+        ui->previewWidget->setStyleSheet("#previewWidget{background: black;}");
+        ui->previewWidget->setAutoFillBackground(true);
+
+        process = new QProcess();
+
+        initSearchText();
+        _acquireThemeinfoList();
+        initComponent();
+        initEnableBtnStatus();
+        initThemeStatus();
+        initIdleSliderStatus();
+    }
     return pluginWidget;
 }
 
-void Screensaver::plugin_delay_control(){
+void Screensaver::plugin_delay_control() {
     // 初始化屏保预览Widget
     initPreviewWidget();
 }
 
-void Screensaver::initComponent(){
+const QString Screensaver::name() const {
+
+    return QStringLiteral("screensaver");
+}
+
+void Screensaver::initSearchText() {
+    //~ contents_path /screensaver/Enable screensaver
+    ui->enableLabel->setText(tr("Enable screensaver"));
+    //~ contents_path /screensaver/Screensaver program
+    ui->programLabel->setText(tr("Screensaver program"));
+    //~ contents_path /screensaver/idle time
+    ui->idleLabel->setText(tr("idle time"));
+}
+
+void Screensaver::initComponent() {
     if (QGSettings::isSchemaInstalled(SCREENSAVER_SCHEMA)) {
         const QByteArray id(SCREENSAVER_SCHEMA);
-        screenlock_settings = new QGSettings(id);
+        screenlock_settings = new QGSettings(id, QByteArray(), this);
 
         connect(screenlock_settings, &QGSettings::changed, [=](QString key) {
             if (key == "lockEnabled") {
@@ -144,11 +141,11 @@ void Screensaver::initComponent(){
         });
     }
 
-    if(QGSettings::isSchemaInstalled(SESSION_SCHEMA)) {
+    if (QGSettings::isSchemaInstalled(SESSION_SCHEMA)) {
         qSessionSetting = new QGSettings(SESSION_SCHEMA, QByteArray(), this);
     }
 
-    if(QGSettings::isSchemaInstalled(SCREENSAVER_SCHEMA)) {
+    if (QGSettings::isSchemaInstalled(SCREENSAVER_SCHEMA)) {
         qScreenSaverSetting = new QGSettings(SCREENSAVER_SCHEMA, QByteArray(), this);
     }
 
@@ -169,7 +166,7 @@ void Screensaver::initComponent(){
     ui->comboBox->addItem(tr("Blank_Only"));
 //    ui->comboBox->addItem(tr("Random"));
     QMap<QString, SSThemeInfo>::iterator it = infoMap.begin();
-    for (int index = 2; it != infoMap.end(); it++, index++){
+    for (int index = 2; it != infoMap.end(); it++, index++) {
         SSThemeInfo info = (SSThemeInfo)it.value();
         ui->comboBox->addItem(info.name);
         ui->comboBox->setItemData(index, QVariant::fromValue(info));
@@ -188,11 +185,6 @@ void Screensaver::initComponent(){
     ui->lockhorizontalLayout->addWidget(uslider);
     ui->lockhorizontalLayout->addSpacing(15);
 
-//    ui->idleSlider->setMinimum(IDLEMIN);
-//    ui->idleSlider->setMaximum(IDLEMAX);
-//    ui->idleSlider->setSingleStep(IDLESTEP);
-//    ui->idleSlider->setPageStep(IDLESTEP);
-
     connect(enableSwitchBtn, &SwitchButton::checkedChanged, this, [=](bool checked) {
         screensaver_settings = g_settings_new(SCREENSAVER_SCHEMA);
         g_settings_set_boolean(screensaver_settings, ACTIVE_KEY, checked);
@@ -202,40 +194,22 @@ void Screensaver::initComponent(){
         g_object_unref(screensaver_settings);
     });
 
-    connect(qScreenSaverSetting, &QGSettings::changed, this, [=](const QString key){
+    connect(qScreenSaverSetting, &QGSettings::changed, this, [=](const QString key) {
         if ("idleActivationEnabled" == key) {
             auto status = qScreenSaverSetting->get(ACTIVE_KEY).toBool();
             enableSwitchBtn->setChecked(status);
         }
     });
 
-
-//    connect(lockSwitchBtn, &SwitchButton::checkedChanged, this, [=](bool checked){
-//        //REVIEW*** g_object_unref faild
-//        //    screensaver_settings = g_settings_new(SCREENSAVER_SCHEMA);
-//        //    g_settings_set_boolean(screensaver_settings, LOCK_KEY, status);
-//        //    if (screensaver_settings)
-//        //            g_object_unref(screensaver_settings);
-//        const QByteArray ba(SCREENSAVER_SCHEMA);
-//        QGSettings * settings = new QGSettings(ba);
-//        settings->set(LOCK_KEY, checked);
-//        delete settings;
-//    });
-
-//    connect(uslider, &QSlider::valueChanged, this, [=](int value){
-//        //刷新分钟显示
-//        ui->idleLineEdit->blockSignals(true);
-//        ui->idleLineEdit->setText(QString::number(value));
-//        ui->idleLineEdit->blockSignals(false);
-//    });
-    connect(uslider, &QSlider::valueChanged, this, [=]{
+    connect(uslider, &QSlider::valueChanged, this, [=] {
         int value = convertToLocktime(uslider->value());
         session_settings = g_settings_new(SESSION_SCHEMA);
         g_settings_set_int(session_settings, IDLE_DELAY_KEY, value);
         g_object_unref(session_settings);
     });
+    connectToServer();
 
-    connect(qSessionSetting, &QGSettings::changed, this,[=](const QString& key){
+    connect(qSessionSetting, &QGSettings::changed, this,[=](const QString& key) {
        if ("idleDelay" == key) {
            auto value = qSessionSetting->get(key).toInt();
            uslider->setValue(lockConvertToSlider(value));
@@ -244,17 +218,16 @@ void Screensaver::initComponent(){
 
     connect(ui->comboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(themesComboxChanged(int)));
 
-
-    connect(ui->previewWidget, &QWidget::destroyed, this, [=]{
+    connect(ui->previewWidget, &QWidget::destroyed, this, [=] {
         closeScreensaver();
     });
 }
 
-void Screensaver::initPreviewWidget(){
+void Screensaver::initPreviewWidget() {
     startupScreensaver();
 }
 
-void Screensaver::initEnableBtnStatus(){
+void Screensaver::initEnableBtnStatus() {
 
     const QByteArray ba(SCREENSAVER_SCHEMA);
     QGSettings * settings = new QGSettings(ba);
@@ -273,18 +246,16 @@ void Screensaver::initEnableBtnStatus(){
     locked = settings->get(LOCK_KEY).toBool();
     initLockBtnStatus(locked);
 
-
     delete settings;
-
 }
 
-void Screensaver::initLockBtnStatus(bool status){
+void Screensaver::initLockBtnStatus(bool status) {
     lockSwitchBtn->blockSignals(true);
     lockSwitchBtn->setChecked(status);
     lockSwitchBtn->blockSignals(false);
 }
 
-void Screensaver::initThemeStatus(){
+void Screensaver::initThemeStatus() {
     int mode;
     char * name;
 
@@ -300,10 +271,10 @@ void Screensaver::initThemeStatus(){
 
     mode = g_settings_get_enum(screensaver_settings, MODE_KEY);
 
-    if (mode == MODE_DEFAULT_UKUI){
+    if (mode == MODE_DEFAULT_UKUI) {
         ui->comboBox->setCurrentIndex(0); //UKUI
     }
-    else if (mode == MODE_BLANK_ONLY){
+    else if (mode == MODE_BLANK_ONLY) {
         ui->comboBox->setCurrentIndex(1); //Black_Only
     }
 //    else if (mode == MODE_RANDOM){
@@ -312,18 +283,19 @@ void Screensaver::initThemeStatus(){
     else{
         gchar ** strv;
         strv = g_settings_get_strv(screensaver_settings, THEMES_KEY);
-        if (strv != NULL){
+        if (strv != NULL) {
             name = g_strdup(strv[0]);
 
             QString dest =  (infoMap.find(name) != infoMap.end()) ? infoMap.value(name).name : "";
 
-            if (dest == "")
-                ui->comboBox->setCurrentIndex(1); //
-            else
+            if (dest == "") {
+                ui->comboBox->setCurrentIndex(1);
+            } else {
                 ui->comboBox->setCurrentText(dest);
-        }
-        else
+            }
+        } else {
             ui->comboBox->setCurrentIndex(1); //no data, default Blank_Only
+        }
         g_strfreev(strv);
     }
     g_object_unref(screensaver_settings);
@@ -331,7 +303,7 @@ void Screensaver::initThemeStatus(){
     ui->comboBox->blockSignals(false);
 }
 
-void Screensaver::initIdleSliderStatus(){
+void Screensaver::initIdleSliderStatus() {
     int minutes;
     session_settings = g_settings_new(SESSION_SCHEMA);
     minutes = g_settings_get_int(session_settings, IDLE_DELAY_KEY);
@@ -340,57 +312,14 @@ void Screensaver::initIdleSliderStatus(){
     uslider->setValue(lockConvertToSlider(minutes));
     uslider->blockSignals(false);
 
-//    ui->idleSlider->blockSignals(true);
-//    ui->idleSlider->setValue(minutes);
-//    ui->idleSlider->blockSignals(false);
-
-//    ui->idleLineEdit->blockSignals(true);
-//    ui->idleLineEdit->setText(QString::number(minutes));
-//    ui->idleLineEdit->blockSignals(true);
-
     g_object_unref(session_settings);
 }
 
-void Screensaver::component_init(){
+void Screensaver::component_init() {
 
-    //设置屏保预览widget的背景为黑色
-//    mPreviewWidget->setStyleSheet("#previewWidget{background: black}");
-
-    //
-//    activeswitchbtn = new SwitchButton();
-//    activeswitchbtn->setAttribute(Qt::WA_DeleteOnClose);
-//    ui->activeHLayout->addWidget(activeswitchbtn);
-//    ui->activeHLayout->addStretch();
-
-//    lockswitchbtn = new SwitchButton();
-//    lockswitchbtn->setAttribute(Qt::WA_DeleteOnClose);
-//    ui->lockHLayout->addWidget(lockswitchbtn);
-//    ui->lockHLayout->addStretch();
-
-//    ui->comboBox->addItem(tr("Blank_Only"));
-//    ui->comboBox->addItem(tr("Random"));
-
-//    QMap<QString, SSThemeInfo>::iterator it = infoMap.begin();
-//    for (int itemsindex = 2; it != infoMap.end(); it++, itemsindex++){
-//        SSThemeInfo info = (SSThemeInfo)it.value();
-//        ui->comboBox->addItem(info.name);
-//        ui->comboBox->setItemData(itemsindex, QVariant::fromValue(info));
-//    }
-
-    //init slider
-//    int min = 1;
-//    int max = 120;
-//    int singlestep = 1;
-
-//    ui->idleSlider->setMinimum(min);
-//    ui->idleSlider->setMaximum(max);
-//    ui->idleSlider->setSingleStep(singlestep);
-//    ui->idleSlider->installEventFilter(this);
-
-//    connect(this, SIGNAL(kill_signals()), this, SLOT(kill_screensaver_preview()));
 }
 
-void Screensaver::status_init(){
+void Screensaver::status_init() {
     int mode;
     char * name;
 
@@ -398,102 +327,70 @@ void Screensaver::status_init(){
 
     screensaver_settings = g_settings_new(SCREENSAVER_SCHEMA);
     mode = g_settings_get_enum(screensaver_settings, MODE_KEY);
-    if (mode == MODE_DEFAULT_UKUI){
+    if (mode == MODE_DEFAULT_UKUI) {
         ui->comboBox->setCurrentIndex(0); //UKUI
     }
-    else if(mode == MODE_BLANK_ONLY){
+    else if(mode == MODE_BLANK_ONLY) {
         ui->comboBox->setCurrentIndex(1); //Black_Only
     }
-    else if (mode == MODE_RANDOM){
+    else if (mode == MODE_RANDOM) {
         ui->comboBox->setCurrentIndex(2); //Random
-    }
-    else{
+    } else {
         gchar ** strv;
         strv = g_settings_get_strv(screensaver_settings, THEMES_KEY);
 
-        if (strv != NULL){
+        if (strv != NULL) {
             name = g_strdup(strv[0]);
             SSThemeInfo info = (SSThemeInfo)infoMap.find(name).value();
             ui->comboBox->setCurrentText(info.name);
-        }
-        else
+        } else {
             ui->comboBox->setCurrentIndex(0); //no data, default Blank_Only
+        }
         g_strfreev(strv);
     }
 
-    //init
-//    bool activation; bool lockable;
-//    activation = g_settings_get_boolean(screensaver_settings, ACTIVE_KEY);
-//    activeswitchbtn->setChecked(activation);
-//    if (activation){
-//        lockable = g_settings_get_boolean(screensaver_settings, LOCK_KEY);
-//        lockswitchbtn->setChecked(lockable);
-//        ui->widget->show();
-//    }
-//    else{
-//        lockswitchbtn->setChecked(false);
-//        ui->widget->hide();
-//    }
-
     g_object_unref(screensaver_settings);
 
     //获取空闲时间
     int minutes;
     minutes = g_settings_get_int(session_settings, IDLE_DELAY_KEY);
     uslider->setValue(lockConvertToSlider(minutes));
-//    ui->idleSlider->setValue(minutes);
-//    ui->idleLabel->setText(QString("%1%2").arg(minutes).arg(tr("minutes")));
 
-
-    //获取功能列表
-//    PublicData * publicdata = new PublicData();
-//    QStringList tmpList = publicdata->subfuncList[SYSTEM];
-
-    //connect
-//    connect(ui->powerBtn, &QPushButton::clicked, this, [=]{pluginWidget->emitting_toggle_signal(tmpList.at(2), SYSTEM, 0);});
-
-//    connect(uslider, SIGNAL(sliderReleased()), this, SLOT(slider_released_slot())); //改gsettings
-//    connect(activeswitchbtn, SIGNAL(checkedChanged(bool)), this, SLOT(activebtn_changed_slot(bool)));
-//    connect(lockswitchbtn, SIGNAL(checkedChanged(bool)), this, SLOT(lockbtn_changed_slot(bool)));
     connect(ui->comboBox, SIGNAL(currentIndexChanged(int)), this, SLOT(combobox_changed_slot(int)));
 
     connect(mPreviewWidget, SIGNAL(destroyed(QObject*)), this, SLOT(kill_screensaver_preview()));
 
-//    delete publicdata;
 }
 
-void Screensaver::startupScreensaver(){
+void Screensaver::startupScreensaver() {
     //关闭屏保
     closeScreensaver();
     qDebug() << Q_FUNC_INFO << ui->previewWidget->winId();
-    if (ui->comboBox->currentIndex() == 0){//UKUI
+    if (ui->comboBox->currentIndex() == 0) {//UKUI
         QStringList args;
         args << "-window-id" << QString::number(ui->previewWidget->winId());
         //启动屏保
         process->startDetached(screensaver_bin, args);
         runStringList.append(screensaver_bin);
-    }
-    else if (ui->comboBox->currentIndex() == 1){//黑屏
+    } else if (ui->comboBox->currentIndex() == 1) {//黑屏
         ui->previewWidget->update();
     }
 //    else if (ui->comboBox->currentIndex() == 2){//随机
 //        ui->previewWidget->update();
 //    }
-    else{//屏保
-
+    else {// 屏保
         SSThemeInfo info = ui->comboBox->currentData().value<SSThemeInfo>();
         QStringList args;
         args << "-window-id" << QString::number(ui->previewWidget->winId());
-        //启动屏保
+        // 启动屏保
         process->startDetached(info.exec, args);
         runStringList.append(info.exec);
     }
-
 }
 
-void Screensaver::closeScreensaver(){
+void Screensaver::closeScreensaver() {
     //杀死分离启动的屏保预览程序
-    if (!runStringList.isEmpty()){
+    if (!runStringList.isEmpty()) {
         process->start(QString("killall"), runStringList);
         process->waitForStarted();
         process->waitForFinished(2000);
@@ -502,22 +399,19 @@ void Screensaver::closeScreensaver(){
     }
 }
 
-void Screensaver::kill_and_start(){
+void Screensaver::kill_and_start() {
     emit kill_signals(); //如果有屏保先杀死
-    if (ui->comboBox->currentIndex() == 0){//UKUI
+    if (ui->comboBox->currentIndex() == 0) {//UKUI
         QStringList args;
         args << "-window-id" << QString::number(mPreviewWidget->winId());
         //启动屏保
         process->startDetached(screensaver_bin, args);
         runStringList.append(screensaver_bin);
-    }
-    else if (ui->comboBox->currentIndex() == 1){//黑屏
+    } else if (ui->comboBox->currentIndex() == 1) {//黑屏
         mPreviewWidget->update();
-    }
-    else if (ui->comboBox->currentIndex() == 2){//随机
+    } else if (ui->comboBox->currentIndex() == 2) {//随机
         mPreviewWidget->update();
-    }
-    else{//屏保
+    } else {//屏保
         SSThemeInfo info = ui->comboBox->currentData().value<SSThemeInfo>();
         QStringList args;
         args << "-window-id" << QString::number(mPreviewWidget->winId());
@@ -527,7 +421,6 @@ void Screensaver::kill_and_start(){
     }
 }
 
-
 int Screensaver::convertToLocktime(const int value) {
     switch (value) {
     case 1:
@@ -594,46 +487,32 @@ int Screensaver::lockConvertToSlider(const int value) {
 
 
 
-void Screensaver::set_idle_gsettings_value(int value){    
+void Screensaver::set_idle_gsettings_value(int value) {
     g_settings_set_int(session_settings, IDLE_DELAY_KEY, value);
 }
 
-void Screensaver::slider_released_slot(){
+void Screensaver::slider_released_slot() {
     int minutes;
 //    minutes = ui->idleSlider->value();
     minutes = convertToLocktime(uslider->value());
     set_idle_gsettings_value(minutes);
 }
 
-void Screensaver::lockbtn_changed_slot(bool status){
-    //REVIEW***  setchecked(false) -> g_object_unref faild
-//    screensaver_settings = g_settings_new(SCREENSAVER_SCHEMA);
-//    g_settings_set_boolean(screensaver_settings, LOCK_KEY, status);
-//    if (screensaver_settings)
-//            g_object_unref(screensaver_settings);
+void Screensaver::lockbtn_changed_slot(bool status) {
     const QByteArray ba(SCREENSAVER_SCHEMA);
     QGSettings * settings = new QGSettings(ba);
     settings->set(LOCK_KEY, status);
     delete settings;
 }
 
-void Screensaver::activebtn_changed_slot(bool status){
+void Screensaver::activebtn_changed_slot(bool status) {
     screensaver_settings = g_settings_new(SCREENSAVER_SCHEMA);
     g_settings_set_boolean(screensaver_settings, ACTIVE_KEY, status);
 
-//    if (status){
-//        ui->widget->show();
-//    }
-//    else{
-//        lockswitchbtn->setChecked(false);
-//        ui->widget->hide();
-
-//    }
     g_object_unref(screensaver_settings);
-
 }
 
-void Screensaver::themesComboxChanged(int index){
+void Screensaver::themesComboxChanged(int index) {
 
     char ** strv = NULL;
 
@@ -658,22 +537,19 @@ void Screensaver::themesComboxChanged(int index){
 
     //刷新预览
     startupScreensaver();
-
 }
 
-void Screensaver::combobox_changed_slot(int index){
+void Screensaver::combobox_changed_slot(int index) {
     char ** strv = NULL;
 
 
     screensaver_settings = g_settings_new(SCREENSAVER_SCHEMA);
-    if (index == 0){ //ukui
+    if (index == 0) { //ukui
         g_settings_set_enum(screensaver_settings, MODE_KEY, MODE_DEFAULT_UKUI);
-    }
-    else if (index == 1){ //Blank_Only
+    } else if (index == 1) { //Blank_Only
         qDebug()<<"this is Blan_only----------------->"<<endl;
         g_settings_set_enum(screensaver_settings, MODE_KEY, MODE_BLANK_ONLY);
-    }
-    else if (index == 10000){ //Random not in
+    } else if (index == 10000) { //Random not in
 //        int mode = MODE_RANDOM;
         g_settings_set_enum(screensaver_settings, MODE_KEY, MODE_RANDOM);
         //REVIEW*** 二维字符数组赋值字符串段错误？
@@ -689,14 +565,13 @@ void Screensaver::combobox_changed_slot(int index){
         const QByteArray ba(SCREENSAVER_SCHEMA);
         QGSettings * settings = new QGSettings(ba);
         QMap<QString, SSThemeInfo>::iterator it = infoMap.begin();
-        for (; it != infoMap.end(); it++){
+        for (; it != infoMap.end(); it++) {
             QString id = QString(it.key());
             valueStringList.append(id);
         }
         settings->set(THEMES_KEY, QVariant(valueStringList));
         delete settings;
-    }
-    else{
+    } else {
         g_settings_set_enum(screensaver_settings, MODE_KEY, MODE_SINGLE);
         //获取当前屏保的id
         QVariant variant = ui->comboBox->itemData(index);
@@ -706,10 +581,6 @@ void Screensaver::combobox_changed_slot(int index){
         qDebug() << Q_FUNC_INFO << "wxy-----------" <<strv;
         g_settings_set_strv(screensaver_settings, THEMES_KEY, (const gchar * const*)strv);
     }
-    //set mode
-//    g_settings_set_enum(screensaver_settings, MODE_KEY, mode);
-    //set themes
-//    g_settings_set_strv(screensaver_settings, THEMES_KEY, (const gchar * const*)strv);
 
     g_object_unref(screensaver_settings);
     g_strfreev(strv);
@@ -718,7 +589,7 @@ void Screensaver::combobox_changed_slot(int index){
     kill_and_start();
 }
 
-void Screensaver::kill_screensaver_preview(){
+void Screensaver::kill_screensaver_preview() {
     //需要手动杀死分离启动的屏保预览程序
 //    if (!killList.isEmpty()){
 //        process->start(QString("killall"), killList);
@@ -729,13 +600,13 @@ void Screensaver::kill_screensaver_preview(){
 //    }
 }
 
-SSThemeInfo Screensaver::_info_new(const char *path){
+SSThemeInfo Screensaver::_info_new(const char *path) {
     SSThemeInfo info;
     GKeyFile * keyfile;
     char * name, * exec;
 
     keyfile = g_key_file_new();
-    if (!g_key_file_load_from_file(keyfile, path, G_KEY_FILE_NONE, NULL)){
+    if (!g_key_file_load_from_file(keyfile, path, G_KEY_FILE_NONE, NULL)) {
         g_key_file_free (keyfile);
         return info;
     }
@@ -752,13 +623,13 @@ SSThemeInfo Screensaver::_info_new(const char *path){
     return info;
 }
 
-SSThemeInfo Screensaver::_newThemeinfo(const char * path){
+SSThemeInfo Screensaver::_newThemeinfo(const char * path) {
     SSThemeInfo info;
     GKeyFile * keyfile;
     char * name, * exec;
 
     keyfile = g_key_file_new();
-    if (!g_key_file_load_from_file(keyfile, path, G_KEY_FILE_NONE, NULL)){
+    if (!g_key_file_load_from_file(keyfile, path, G_KEY_FILE_NONE, NULL)) {
         g_key_file_free (keyfile);
         return info;
     }
@@ -776,7 +647,7 @@ SSThemeInfo Screensaver::_newThemeinfo(const char * path){
     return info;
 }
 
-void Screensaver::_acquireThemeinfoList(){
+void Screensaver::_acquireThemeinfoList() {
     GDir * dir;
     const char * name;
 
@@ -798,7 +669,7 @@ void Screensaver::_acquireThemeinfoList(){
     g_dir_close(dir);
 }
 
-void Screensaver::init_theme_info_map(){
+void Screensaver::init_theme_info_map() {
     GDir * dir;
     const char * name;
 
@@ -819,3 +690,25 @@ void Screensaver::init_theme_info_map(){
     }
     g_dir_close(dir);
 }
+
+void Screensaver::connectToServer(){
+    m_cloudInterface = new QDBusInterface("org.kylinssoclient.dbus",
+                                          "/org/kylinssoclient/path",
+                                          "org.freedesktop.kylinssoclient.interface",
+                                          QDBusConnection::sessionBus());
+    if (!m_cloudInterface->isValid())
+    {
+        qDebug() << "fail to connect to service";
+        qDebug() << qPrintable(QDBusConnection::systemBus().lastError().message());
+        return;
+    }
+    QDBusConnection::sessionBus().connect(QString(), QString("/org/kylinssoclient/path"), QString("org.freedesktop.kylinssoclient.interface"), "keyChanged", this, SLOT(keyChangedSlot(QString)));
+    // 将以后所有DBus调用的超时设置为 milliseconds
+    m_cloudInterface->setTimeout(2147483647); // -1 为默认的25s超时
+}
+
+void Screensaver::keyChangedSlot(const QString &key) {
+    if(key == "ukui-screensaver") {
+        initThemeStatus();
+    }
+}
