@@ -1,3 +1,4 @@
+
 /* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
  *
  * Copyright (C) 2019 Tianjin KYLIN Information Technology Co., Ltd.
@@ -21,61 +22,59 @@
 #include "ui_theme.h"
 
 #include <QGSettings>
-
-#include "SwitchButton/switchbutton.h"
-
-#include "themewidget.h"
-#include "widgetgroup.h"
-#include "cursor/xcursortheme.h"
-
-#include "../../../shell/customstyle.h"
-
 #include <QDebug>
 #include <QtDBus/QDBusConnection>
 #include <QtConcurrent>
-/**
- * GTK主题
- */
+
+#include "SwitchButton/switchbutton.h"
+#include "cursor/xcursortheme.h"
+#include "../../../shell/customstyle.h"
+
+// GTK主题
 #define THEME_GTK_SCHEMA "org.mate.interface"
-#define MODE_GTK_KEY "gtk-theme"
-/* GTK图标主题 */
-#define ICON_GTK_KEY "icon-theme"
+#define MODE_GTK_KEY     "gtk-theme"
 
-/**
- * QT主题
- */
+// GTK图标主题
+#define ICON_GTK_KEY    "icon-theme"
+
+// QT主题
 #define THEME_QT_SCHEMA "org.ukui.style"
-#define MODE_QT_KEY "style-name"
-#define THEME_TRAN_KEY "menu-transparency"
-#define PEONY_TRAN_KEY "peony-side-bar-transparency"
+#define MODE_QT_KEY     "style-name"
+#define THEME_TRAN_KEY  "menu-transparency"
+#define PEONY_TRAN_KEY  "peony-side-bar-transparency"
 
-/* QT图标主题 */
-#define ICON_QT_KEY "icon-theme-name"
+// QT图标主题
+#define ICON_QT_KEY     "icon-theme-name"
 
-/**
- * 窗口管理器Marco主题
- */
-#define MARCO_SCHEMA "org.gnome.desktop.wm.preferences"
+// 窗口管理器Marco主题
+#define MARCO_SCHEMA    "org.gnome.desktop.wm.preferences"
 #define MARCO_THEME_KEY "theme"
 
-#define ICONTHEMEPATH "/usr/share/icons/"
-#define SYSTHEMEPATH "/usr/share/themes/"
+#define ICONTHEMEPATH       "/usr/share/icons/"
+#define SYSTHEMEPATH        "/usr/share/themes/"
 #define CURSORS_THEMES_PATH "/usr/share/icons/"
 
 #define CURSOR_THEME_SCHEMA "org.ukui.peripherals-mouse"
-#define CURSOR_THEME_KEY "cursor-theme"
+#define CURSOR_THEME_KEY    "cursor-theme"
 
 #define ICONWIDGETHEIGH 74
 
-/**
- * 透明度设置
- */
-#define PERSONALSIE_SCHEMA "org.ukui.control-center.personalise"
-#define PERSONALSIE_TRAN_KEY "transparency"
+// 透明度设置
+#define PERSONALSIE_SCHEMA     "org.ukui.control-center.personalise"
+#define PERSONALSIE_TRAN_KEY   "transparency"
 #define PERSONALSIE_BLURRY_KEY "blurry"
+#define PERSONALSIE_EFFECT_KEY "effect"
 
-const QString defCursor = "DMZ-White";
-const int transparency = 95;
+const QString kDefCursor =           "DMZ-White";
+const QString UbuntuVesionEnhance =  "20.10";
+const QString kXder =                "XRender";
+
+const int transparency = 75;
+
+const QStringList effectList {"blur", "kwin4_effect_translucency", "kwin4_effect_maximize", "zoom"};
+const QStringList kIconsList {"blueman", "disk-burner", "firefox", "kylin-video", "kylin-assistant", "kylin-scanner", "kylin-ipmsg"};
+
+const QStringList kExcludeIcon {"ukui-icon-theme-default", "ukui-icon-theme-classical", "ukui-icon-theme-basic"};
 
 namespace {
 
@@ -106,75 +105,40 @@ Theme::Theme()
     ui = new Ui::Theme;
     pluginWidget = new QWidget;
     pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
-    ui->setupUi(pluginWidget);
-
     pluginName = tr("Theme");
     pluginType = PERSONALIZED;
-
+    ui->setupUi(pluginWidget);
     ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
+    ui->iconLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
+    ui->cursorLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
+    ui->effectLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
 
-    settingsCreate = false;
+    setupGSettings();
+    initSearchText();
 
-    const QByteArray id(THEME_GTK_SCHEMA);
-    const QByteArray idd(THEME_QT_SCHEMA);
-    const QByteArray iid(CURSOR_THEME_SCHEMA);
-    const QByteArray iiid(PERSONALSIE_SCHEMA);
-    if (QGSettings::isSchemaInstalled(iiid)) {
-        personliseGsettings = new QGSettings(iiid);
-    }
     //设置组件
     setupComponent();
-
-    // init kwin settings
     setupSettings();
-
-    if (QGSettings::isSchemaInstalled(id) && QGSettings::isSchemaInstalled(idd)
-            && QGSettings::isSchemaInstalled(iid)){
-        gtkSettings = new QGSettings(id);
-        qtSettings = new QGSettings(idd);
-        curSettings = new QGSettings(iid);
-
-        settingsCreate = true;
-
-        initThemeMode();
-        initIconTheme();
-        initCursorTheme();
-//        initEffectSettings();
-        initConnection();
-    } else {
-        qCritical() << THEME_GTK_SCHEMA << "or" << THEME_QT_SCHEMA << "or" << CURSOR_THEME_SCHEMA << "not installed\n";
-    }
-
+    initThemeMode();
+    initIconTheme();
+    initCursorTheme();
+    initConnection();
 }
 
 Theme::~Theme()
 {
     delete ui;
-    if (settingsCreate){
-        delete gtkSettings;
-        delete qtSettings;
-        delete curSettings;
-    }
-    if (kwinSettings ){
-        delete kwinSettings;
-    }
-    if (kwinGsettings) {
-        delete kwinGsettings;
-    }
-    if (personliseGsettings) {
-        delete personliseGsettings;
-    }
 }
 
-QString Theme::get_plugin_name(){
+QString Theme::get_plugin_name() {
     return pluginName;
 }
 
-int Theme::get_plugin_type(){
+int Theme::get_plugin_type() {
     return pluginType;
 }
 
-QWidget *Theme::get_plugin_ui(){
+QWidget *Theme::get_plugin_ui() {
     return pluginWidget;
 }
 
@@ -182,14 +146,37 @@ void Theme::plugin_delay_control(){
 
 }
 
+const QString Theme::name() const {
+
+    return QStringLiteral("theme");
+}
+
+void Theme::initSearchText() {
+    //~ contents_path /theme/Theme Mode
+    ui->titleLabel->setText(tr("Theme Mode"));
+    //~ contents_path /theme/Icon theme
+    ui->iconLabel->setText(tr("Icon theme"));
+    //~ contents_path /theme/Cursor theme
+    ui->cursorLabel->setText(tr("Cursor theme"));
+    //~ contents_path /theme/Performance mode
+    ui->perforLabel->setText(tr("Performance mode"));
+    //~ contents_path /theme/Transparency
+    ui->transparencyLabel->setText(tr("Transparency"));
+}
+
 void Theme::setupSettings() {
     QString filename = QDir::homePath() + "/.config/ukui-kwinrc";
-    kwinSettings = new QSettings(filename, QSettings::IniFormat);
+    kwinSettings = new QSettings(filename, QSettings::IniFormat, this);
+
+    QStringList keys = kwinSettings->childGroups();
 
     kwinSettings->beginGroup("Plugins");
-
     bool kwin = kwinSettings->value("blurEnabled", kwin).toBool();
 
+    if (!kwinSettings->childKeys().contains("blurEnabled")) {
+        kwin = true;
+    }
+
     kwinSettings->endGroup();
 
     effectSwitchBtn->setChecked(kwin);
@@ -204,17 +191,34 @@ void Theme::setupSettings() {
     } else {
         ui->transFrame->setVisible(false);
     }
+
+    if (keys.contains("Compositing")) {
+        kwinSettings->beginGroup("Compositing");
+        QString xder;
+        bool kwinOG = false;
+        bool kwinEN = true;
+        xder = kwinSettings->value("Backend", xder).toString();
+        kwinOG = kwinSettings->value("OpenGLIsUnsafe", kwinOG).toBool();
+        kwinEN = kwinSettings->value("Enabled", kwinEN).toBool();
+        if (xder == kXder || kwinOG || !kwinEN) {
+            ui->effectFrame->setVisible(false);
+            ui->transFrame->setVisible(false);
+            ui->effectLabel->setVisible(false);
+            personliseGsettings->set(PERSONALSIE_EFFECT_KEY, false);
+        }
+        kwinSettings->endGroup();
+    }
 }
 
-void Theme::setupComponent(){
+void Theme::setupComponent() {
 
-    ui->lightButton->hide();
+    ui->lightButton->setVisible(getSystemVersion());
     //隐藏现阶段不支持功能
     ui->controlLabel->hide();
     ui->controlWidget->hide();
 
-    ui->defaultButton->setProperty("value", "ukui-default");
-//    ui->lightButton->setProperty("value", "ukui-default");
+    ui->defaultButton->setProperty("value", "ukui");
+    ui->lightButton->setProperty("value", "ukui-light");
     ui->darkButton->setProperty("value", "ukui-dark");
 
     buildThemeModeBtn(ui->defaultButton, tr("Default"), "default");
@@ -222,19 +226,14 @@ void Theme::setupComponent(){
     buildThemeModeBtn(ui->darkButton, tr("Dark"), "dark");
 
     ui->tranSlider->setRange(35, 100);
-    ui->tranSlider->setTickInterval(1);
-    ui->tranSlider->setPageStep(1);
 
-    ui->tranSlider->setValue(static_cast<int>(personliseGsettings->get(PERSONALSIE_TRAN_KEY).toDouble() * 100));
-    ui->tranLabel->setText(QString::number(static_cast<double>(ui->tranSlider->value())/100.0));
-    connect(ui->tranSlider, &QSlider::valueChanged, [=](int value){
-        personliseGsettings->set(PERSONALSIE_TRAN_KEY, static_cast<double>(value)/100.0);
-        qtSettings->set(THEME_TRAN_KEY, value);
-        qtSettings->set(PEONY_TRAN_KEY, value);
-        ui->tranLabel->setText(QString::number(static_cast<double>(ui->tranSlider->value())/100.0));
+    ui->tranSlider->setValue(static_cast<int>(personliseGsettings->get(PERSONALSIE_TRAN_KEY).toDouble() * 100.0));
+    connect(ui->tranSlider, &QSlider::valueChanged, this, [=]() {
+        personliseGsettings->set(PERSONALSIE_TRAN_KEY,(static_cast<int>(ui->tranSlider->value()) / 100.0));
+        qtSettings->set(THEME_TRAN_KEY, ui->tranSlider->value());
+        qtSettings->set(PEONY_TRAN_KEY, ui->tranSlider->value());
     });
     setupControlTheme();
-
 //    ui->effectLabel->hide();
 //    ui->effectWidget->hide();
 
@@ -244,17 +243,10 @@ void Theme::setupComponent(){
 
     ui->kwinFrame->setVisible(false);
     ui->transFrame->setVisible(true);
-
-#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
-    ui->transFrame->setVisible(false);
-    ui->effectFrame->setVisible(false);
-#else
-#endif
 }
 
 void Theme::buildThemeModeBtn(QPushButton *button, QString name, QString icon){
     //设置默认按钮
-//    button->setStyleSheet("QPushButton{background: #ffffff; border: none;}");
 
     QVBoxLayout * baseVerLayout = new QVBoxLayout(button);
     baseVerLayout->setSpacing(8);
@@ -305,67 +297,66 @@ void Theme::buildThemeModeBtn(QPushButton *button, QString name, QString icon){
     button->setLayout(baseVerLayout);
 }
 
-void Theme::initThemeMode(){
+void Theme::initThemeMode() {
+    // 获取当前主题
+    QString currentThemeMode = qtSettings->get(MODE_QT_KEY).toString();
+    if ("ukui" == currentThemeMode) {
+        ui->themeModeBtnGroup->buttonClicked(ui->defaultButton);
+    } else if ("ukui-dark" == currentThemeMode){
+        ui->themeModeBtnGroup->buttonClicked(ui->darkButton);
+    } else {
+        ui->themeModeBtnGroup->buttonClicked(ui->lightButton);
+    }
+
+    qApp->setStyle(new InternalStyle("ukui"));
+
     //监听主题改变
-    connect(qtSettings, &QGSettings::changed, this, [=](const QString &key){
+    connect(qtSettings, &QGSettings::changed, this, [=](const QString &key) {
         if (key == "styleName") {
             //获取当前主题
             QString currentThemeMode = qtSettings->get(key).toString();
-            writeKwinSettings(true, currentThemeMode);
             for (QAbstractButton * button : ui->themeModeBtnGroup->buttons()){
                 QVariant valueVariant = button->property("value");
                 if (valueVariant.isValid() && valueVariant.toString() == currentThemeMode) {
+                    disconnect(ui->themeModeBtnGroup, SIGNAL(buttonClicked(QAbstractButton*)), this, SLOT(themeBtnClickSlot(QAbstractButton*)));
                     button->click();
+                    connect(ui->themeModeBtnGroup, SIGNAL(buttonClicked(QAbstractButton*)), this, SLOT(themeBtnClickSlot(QAbstractButton*)));
                 }
             }
+            qApp->setStyle(new InternalStyle("ukui"));
         }
     });
 
-    //获取当前主题
-    QString currentThemeMode = qtSettings->get(MODE_QT_KEY).toString();
-    qApp->setStyle(new InternalStyle(currentThemeMode));
-    //设置界面
-    for (QAbstractButton * button : ui->themeModeBtnGroup->buttons()){
-        QVariant valueVariant = button->property("value");
-        if (valueVariant.isValid() && valueVariant.toString() == currentThemeMode)
-            button->click();
-//            button->setChecked(true);
-    }
-
-#if QT_VERSION <= QT_VERSION_CHECK(5, 12, 0)
-    connect(ui->themeModeBtnGroup, static_cast<void (QButtonGroup::*)(QAbstractButton *)>(&QButtonGroup::buttonClicked), [=](QAbstractButton * button){
-#else
-    connect(ui->themeModeBtnGroup, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this, [=](QAbstractButton * button){
-#endif
-//        //设置主题
-        QString themeMode = button->property("value").toString();
-        QString currentThemeMode = qtSettings->get(MODE_QT_KEY).toString();
-
-
-        qApp->setStyle(new InternalStyle(themeMode));
-        if (QString::compare(currentThemeMode, themeMode)){
-            QString tmpMode;
-            if ("ukui-dark" == themeMode) {
-                tmpMode = "ukui-black";
-            } else {
-                tmpMode = "ukui-white";
-            }
-            gtkSettings->set(MODE_GTK_KEY, tmpMode);
-
-            QtConcurrent::run([=](){
-                qtSettings->set(MODE_QT_KEY, themeMode);
-            });
-            writeKwinSettings(true, themeMode);
-        }
+    connect(gtkSettings,&QGSettings::changed,this,[=] (const QString &key) {
+       if(key == "iconTheme") {
+           QString icoName = qtSettings->get(ICON_QT_KEY).toString();
+           setCheckStatus(ui->iconThemeVerLayout, icoName, ICON);
+       }
     });
+
+    connect(curSettings,&QGSettings::changed,this,[=](const QString &key) {
+       if(key == "cursorTheme") {
+            QString cursorTheme = curSettings->get(CURSOR_THEME_KEY).toString();
+            setCheckStatus(ui->cursorVerLayout, cursorTheme, CURSOR);
+       }
+    });
+
+    connect(personliseGsettings, &QGSettings::changed,this,[=] (const QString &key) {
+       if(key == "effect") {
+           bool effectEnabled = personliseGsettings->get("effect").toBool();
+           effectSwitchBtn->setChecked(effectEnabled);
+       }
+    });
+
+    connect(ui->themeModeBtnGroup, SIGNAL(buttonClicked(QAbstractButton*)), this, SLOT(themeBtnClickSlot(QAbstractButton*)));
 }
 
-void Theme::initIconTheme(){
+void Theme::initIconTheme() {
     //获取当前图标主题(以QT为准，后续可以对比GTK两个值)
     QString currentIconTheme = qtSettings->get(ICON_QT_KEY).toString();
 
     //构建图标主题Widget Group，方便更新选中/非选中状态
-    WidgetGroup * iconThemeWidgetGroup = new WidgetGroup;
+    iconThemeWidgetGroup = new WidgetGroup;
     connect(iconThemeWidgetGroup, &WidgetGroup::widgetChanged, [=](ThemeWidget * preWidget, ThemeWidget * curWidget){
         if (preWidget)
             preWidget->setSelectedStatus(false);
@@ -381,25 +372,28 @@ void Theme::initIconTheme(){
     QDir themesDir = QDir(ICONTHEMEPATH);
 
     foreach (QString themedir, themesDir.entryList(QDir::Dirs)) {
-        if (themedir.startsWith("ukui-icon-theme-")){
+        if (themedir.startsWith("ukui")){
+
             QDir appsDir = QDir(ICONTHEMEPATH + themedir + "/48x48/apps/");
+
+            if (kExcludeIcon.contains(themedir, Qt::CaseInsensitive)) {
+                continue;
+            }
             appsDir.setFilter(QDir::Files | QDir::NoSymLinks);
             QStringList appIconsList = appsDir.entryList();
 
             QStringList showIconsList;
-            for (int i = 0; i < appIconsList.size(); i++){
-                if (i%64 == 0 && i < 6 * 64){
-                    showIconsList.append(appsDir.path() + "/" + appIconsList.at(i));
-                }
+            for (int i = 0; i < kIconsList.size(); i++) {
+                showIconsList.append(appsDir.path() + "/" + kIconsList.at(i));
             }
 
             ThemeWidget * widget = new ThemeWidget(QSize(48, 48), dullTranslation(themedir.section("-", -1, -1, QString::SectionSkipEmpty)), showIconsList);
-//            widget->setFrameShape(QFrame::Shape::Box);
             widget->setValue(themedir);
-            //加入Layout
+
+            // 加入Layout
             ui->iconThemeVerLayout->addWidget(widget);
 
-            //加入WidgetGround实现获取点击前Widget
+            // 加入WidgetGround实现获取点击前Widget
             iconThemeWidgetGroup->addWidget(widget);
 
             if (themedir == currentIconTheme){
@@ -434,8 +428,6 @@ void Theme::setupControlTheme(){
 //        button->setStyleSheet(btnStyle);
         colorBtnGroup->addButton(button, colorStringList.indexOf(color));
 
-
-
         QVBoxLayout * colorVerLayout = new QVBoxLayout();
         colorVerLayout->setSpacing(0);
         colorVerLayout->setMargin(0);
@@ -472,13 +464,12 @@ void Theme::setupControlTheme(){
 void Theme::initCursorTheme(){
 
     QStringList cursorThemes = _getSystemCursorThemes();
-//    qDebug() << cursorThemes;
 
     //获取当前指针主题
     QString currentCursorTheme;
     currentCursorTheme = curSettings->get(CURSOR_THEME_KEY).toString();
 
-    WidgetGroup * cursorThemeWidgetGroup = new WidgetGroup;
+    cursorThemeWidgetGroup = new WidgetGroup(this);
     connect(cursorThemeWidgetGroup, &WidgetGroup::widgetChanged, [=](ThemeWidget * preWidget, ThemeWidget * curWidget){
         if (preWidget)
             preWidget->setSelectedStatus(false);
@@ -487,6 +478,26 @@ void Theme::initCursorTheme(){
         QString value = curWidget->getValue();
         //设置光标主题
         curSettings->set(CURSOR_THEME_KEY, value);
+
+#if QT_VERSION <= QT_VERSION_CHECK(5,12,0)
+
+#else
+        QString filename = QDir::homePath() + "/.config/kcminputrc";
+        QSettings *mouseSettings = new QSettings(filename, QSettings::IniFormat);
+
+        mouseSettings->beginGroup("Mouse");
+        mouseSettings->setValue("cursorTheme", value);
+        mouseSettings->endGroup();
+
+        delete mouseSettings;
+
+        QDBusMessage message = QDBusMessage::createSignal("/KGlobalSettings", "org.kde.KGlobalSettings", "notifyChange");
+        QList<QVariant> args;
+        args.append(5);
+        args.append(0);
+        message.setArguments(args);
+        QDBusConnection::sessionBus().send(message);
+#endif
     });
 
     for (QString cursor : cursorThemes){
@@ -502,7 +513,6 @@ void Theme::initCursorTheme(){
         }
 
         ThemeWidget * widget  = new ThemeWidget(QSize(24, 24), cursor, cursorVec);
-//        widget->setFrameShape(QFrame::Shape::Box);
         widget->setValue(cursor);
 
         //加入Layout
@@ -512,19 +522,17 @@ void Theme::initCursorTheme(){
         cursorThemeWidgetGroup->addWidget(widget);
 
         //初始化指针主题选中界面
-        if (currentCursorTheme == cursor || (currentCursorTheme.isEmpty() && cursor == defCursor)){
+        if (currentCursorTheme == cursor || (currentCursorTheme.isEmpty() && cursor == kDefCursor)){
             cursorThemeWidgetGroup->setCurrentWidget(widget);
             widget->setSelectedStatus(true);
         } else {
             widget->setSelectedStatus(false);
         }
-
     }
 }
 
-void Theme::initEffectSettings(){
-//    ui->effectLabel->hide();
-//    ui->effectWidget->hide();
+void Theme::initEffectSettings() {
+
 }
 
 void Theme::initConnection() {
@@ -532,13 +540,32 @@ void Theme::initConnection() {
     connect(ui->resetBtn, &QPushButton::clicked, this, &Theme::resetBtnClickSlot);
 
     connect(effectSwitchBtn, &SwitchButton::checkedChanged, [this](bool checked) {
+        if (!checked) {
+            personliseGsettings->set(PERSONALSIE_TRAN_KEY, 1.0);
+            qtSettings->set(THEME_TRAN_KEY, 100);
+            qtSettings->set(PEONY_TRAN_KEY, 100);
+            ui->tranSlider->setValue(100);
+        } else {
+            ui->lowLabel->setPixmap(QPixmap("://img/plugins/theme/opacitylow.svg"));
+            ui->highlabel->setPixmap(QPixmap("://img/plugins/theme/opacityhigh.svg"));
+        }
+        // 提供给外部监听特效接口
+        personliseGsettings->set(PERSONALSIE_EFFECT_KEY, checked);
         QString currentThemeMode = qtSettings->get(MODE_QT_KEY).toString();
         ui->transFrame->setVisible(checked);
-        writeKwinSettings(checked, currentThemeMode);
+        writeKwinSettings(checked, currentThemeMode, true);
     });
+
+#if QT_VERSION < QT_VERSION_CHECK(5, 7, 0)
+    ui->transFrame->setVisible(false);
+    ui->effectFrame->setVisible(false);
+    ui->effectLabel->setVisible(false);
+#else
+
+#endif
 }
 
-QStringList Theme::_getSystemCursorThemes(){
+QStringList Theme::_getSystemCursorThemes() {
     QStringList themes;
     QDir themesDir(CURSORS_THEMES_PATH);
 
@@ -555,119 +582,182 @@ QStringList Theme::_getSystemCursorThemes(){
     return themes;
 }
 
-QString Theme::dullTranslation(QString str){
+bool Theme::getSystemVersion() {
+    QString versionPath = "/etc/os-release";
+    QStringList osRes =  readFile(versionPath);
+    QString version;
+
+    for (QString str : osRes) {
+        if (str.contains("VERSION_ID=")) {
+            int index = str.indexOf("VERSION_ID=");
+            int startIndex = index + 12;
+            int length = str.length() - startIndex - 1;
+            version = str.mid(startIndex, length);
+        }
+    }
+    if (UbuntuVesionEnhance == version) {
+        return true;
+    }
+    return false;
+}
+
+QStringList Theme::readFile(QString filepath) {
+    QStringList fileCont;
+    QFile file(filepath);
+    if (file.exists()) {
+        if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
+            qWarning() << "ReadFile() failed to open" << filepath;
+            return QStringList();
+        }
+        QTextStream textStream(&file);
+        while (!textStream.atEnd()) {
+            QString line= textStream.readLine();
+            line.remove('\n');
+            fileCont<<line;
+        }
+        file.close();
+        return fileCont;
+    } else {
+        qWarning() << filepath << " not found"<<endl;
+        return QStringList();
+    }
+}
+
+void Theme::setupGSettings() {
+    const QByteArray id(THEME_GTK_SCHEMA);
+    const QByteArray idd(THEME_QT_SCHEMA);
+    const QByteArray iid(CURSOR_THEME_SCHEMA);
+    const QByteArray iiid(PERSONALSIE_SCHEMA);
+    gtkSettings = new QGSettings(id, QByteArray(), this);
+    qtSettings = new QGSettings(idd, QByteArray(), this);
+    curSettings = new QGSettings(iid, QByteArray(), this);
+    personliseGsettings = new QGSettings(iiid, QByteArray(), this);
+}
+
+QString Theme::dullTranslation(QString str) {
     if (!QString::compare(str, "basic")){
         return QObject::tr("basic");
     } else if (!QString::compare(str, "classical")){
         return QObject::tr("classical");
     } else if (!QString::compare(str, "default")){
         return QObject::tr("default");
-    } else
-        return QObject::tr("Unknown");
+    } else {
+        return QObject::tr("default");
+    }
 }
 
 // reset all of themes, include cursor, icon,and etc...
 void Theme::resetBtnClickSlot() {
 
-    // reset theme(because MODE_QT_KEY's default is null, use "SET" to reset default key )
-//    QString theme = "ukui-default";
-//    qtSettings->set(MODE_QT_KEY, theme);
-//    gtkSettings->set(MODE_GTK_KEY, theme);
-//    emit ui->defaultButton->clicked();
     emit ui->themeModeBtnGroup->buttonClicked(ui->defaultButton);
 
-    ui->tranSlider->setValue(transparency);
-
-//    ui->defaultButton->setChecked(true);
-
     // reset cursor default theme
-    QString cursorTheme = "DMZ-White";
-    curSettings->set(CURSOR_THEME_KEY,cursorTheme);
+    curSettings->reset(CURSOR_THEME_KEY);
+    QString cursorTheme = kDefCursor;
+    QString defaultCursor = curSettings->get(CURSOR_THEME_KEY).toString();
+    if (defaultCursor.isEmpty()) {
+        curSettings->set(CURSOR_THEME_KEY, kDefCursor);
+    } else {
+        cursorTheme = defaultCursor;
+    }
 
-    //reset icon default theme
+    // reset icon default theme
     qtSettings->reset(ICON_QT_KEY);
-    qtSettings->reset(THEME_TRAN_KEY);
-    qtSettings->reset(PEONY_TRAN_KEY);
-    gtkSettings->reset(ICON_GTK_KEY);
 
-    ui->tranSlider->setValue(transparency);
+    if (ui->effectFrame->isVisible()) {
+        effectSwitchBtn->setChecked(true);
+    }
 
-    clearLayout(ui->iconThemeVerLayout->layout(), true);
-    clearLayout(ui->cursorVerLayout->layout(), true);
+    QString icoName = qtSettings->get(ICON_QT_KEY).toString();
 
-    initThemeMode();
-    initIconTheme();
-    initCursorTheme();
+    setCheckStatus(ui->iconThemeVerLayout, icoName, ICON);
+    setCheckStatus(ui->cursorVerLayout, cursorTheme, CURSOR);
 }
 
-void Theme::writeKwinSettings(bool change, QString theme, int effect) {
+void Theme::writeKwinSettings(bool change, QString theme, bool effect) {
+    Q_UNUSED(theme);
+    Q_UNUSED(effect);
 
-    QString th = "";
-    if ("ukui-default" == theme) {
-        th = "__aurorae__svg__Ukui-classic";
-    } else if ("ukui-dark" == theme){
-        th = "__aurorae__svg__Ukui-classic-dark";
-    }
     if (!change) {
-        kwinSettings->clear();
         kwinSettings->beginGroup("Plugins");
-        kwinSettings->setValue("blurEnabled",false);
-        kwinSettings->setValue("contrastEnabled",false);
-        kwinSettings->setValue("kwin4_effect_dialogparentEnabled",false);
-        kwinSettings->setValue("kwin4_effect_fadingpopupsEnabled",false);
-        kwinSettings->setValue("kwin4_effect_frozenappEnabled",false);
-        kwinSettings->setValue("kwin4_effect_loginEnabled",false);
-        kwinSettings->setValue("kwin4_effect_logoutEnabled",false);
-        kwinSettings->setValue("kwin4_effect_maximizeEnabled",false);
-        kwinSettings->setValue("kwin4_effect_maximizeEnabled",false);
-        kwinSettings->setValue("kwin4_effect_morphingpopupsEnabled",false);
-        kwinSettings->setValue("kwin4_effect_squashEnabled",false);
-        kwinSettings->setValue("kwin4_effect_translucencyEnabled",false);
-        kwinSettings->setValue("presentwindowsEnabled",false);
-        kwinSettings->setValue("screenedgeEnabled",false);
-        kwinSettings->setValue("slideEnabled",false);
-        kwinSettings->setValue("slidingpopupsEnabled",false);
-        kwinSettings->setValue("zoomEnabled",false);
+        kwinSettings->setValue("blurEnabled", false);
+        kwinSettings->setValue("kwin4_effect_maximizeEnabled", false);
+        kwinSettings->setValue("kwin4_effect_translucencyEnabled", false);
+        kwinSettings->setValue("zoomEnabled", false);
         kwinSettings->endGroup();
-    } else {
-        kwinSettings->clear();
-        kwinSettings->beginGroup("Plugins");
-        kwinSettings->setValue("blurEnabled",true);
-        kwinSettings->endGroup();
-    }
-
-    if (!th.isEmpty()) {
-        kwinSettings->beginGroup("org.kde.kdecoration2");
-        kwinSettings->setValue("theme", th);
-        kwinSettings->setValue("library", "org.ukui.kwin.aurorae");
-        kwinSettings->endGroup();
-    }
-
-    kwinSettings->sync();
-
-#if QT_VERSION <= QT_VERSION_CHECK(5,12,0)
+#if QT_VERSION <= QT_VERSION_CHECK(5, 12, 0)
 
 #else
-        QDBusMessage message = QDBusMessage::createSignal("/KWin", "org.ukui.KWin", "reloadConfig");
-        QDBusConnection::sessionBus().send(message);
+        for (int i = 0; i < effectList.length(); i++) {
+            QDBusMessage message = QDBusMessage::createMethodCall("org.ukui.KWin",
+                                                       "/Effects",
+                                                       "org.ukui.kwin.Effects",
+                                                       "unloadEffect");
+            message << effectList.at(i);
+            QDBusConnection::sessionBus().send(message);
+        }
 #endif
+    } else {
+        kwinSettings->beginGroup("Plugins");
+        kwinSettings->setValue("blurEnabled", true);
+        kwinSettings->setValue("kwin4_effect_maximizeEnabled", true);
+        kwinSettings->setValue("kwin4_effect_translucencyEnabled", true);
+        kwinSettings->setValue("zoomEnabled", true);
+        kwinSettings->endGroup();
+#if QT_VERSION <= QT_VERSION_CHECK(5, 12, 0)
+
+#else
+        // 开启模糊特效：
+        for (int i = 0; i < effectList.length(); i++) {
+
+            QDBusMessage message = QDBusMessage::createMethodCall("org.ukui.KWin",
+                                                                  "/Effects",
+                                                                  "org.ukui.kwin.Effects",
+                                                                  "loadEffect");
+            message << effectList.at(i);
+            QDBusConnection::sessionBus().send(message);
+        }
+#endif
+
+    }
+    kwinSettings->sync();
 }
 
-void Theme::clearLayout(QLayout* mlayout, bool deleteWidgets)
-{
-    if ( mlayout->layout() != NULL )
-    {
-        QLayoutItem* item;
-        while ( ( item = mlayout->layout()->takeAt( 0 ) ) != NULL )
-        {
-            delete item->widget();
-            delete item;
+void Theme::themeBtnClickSlot(QAbstractButton *button) {
+    // 设置主题
+     QString themeMode = button->property("value").toString();
+     QString currentThemeMode = qtSettings->get(MODE_QT_KEY).toString();
+
+     if (QString::compare(currentThemeMode, themeMode)) {
+         gtkSettings->set(MODE_GTK_KEY, themeMode);
+
+         QtConcurrent::run([=](){
+             qtSettings->set(MODE_QT_KEY, themeMode);
+         });
+     }
+}
+
+void Theme::setCheckStatus(QLayout *mlayout, QString checkName, ThemeType type) {
+    QLayoutItem *item;
+    if (mlayout->layout() != NULL ) {
+        int size = mlayout->layout()->count();
+        for (int i = 0; i < size; i++) {
+            item = mlayout->layout()->itemAt(i);
+            ThemeWidget *themeWdt = static_cast<ThemeWidget *>(item->widget());
+            themeWdt->setSelectedStatus(false);
+            if (themeWdt->getValue() == checkName) {
+                themeWdt->setSelectedStatus(true);
+                if (type == ICON) {
+                    iconThemeWidgetGroup->setCurrentWidget(themeWdt);
+                } else {
+                    cursorThemeWidgetGroup->setCurrentWidget(themeWdt);
+                }
+            }
         }
     }
 }
 
-double Theme::convertToTran(const int value)
-{
+double Theme::convertToTran(const int value) {
     switch (value) {
     case 1:
         return 0.2;
@@ -690,17 +780,16 @@ double Theme::convertToTran(const int value)
     }
 }
 
-int Theme::tranConvertToSlider(const double value)
-{
+int Theme::tranConvertToSlider(const double value) {
     if (0.2 ==  value) {
         return 1;
-    } else if (0.4 ==  value){
+    } else if (0.4 ==  value) {
         return 2;
-    } else if (0.6 ==  value){
+    } else if (0.6 ==  value) {
         return 3;
-    } else if (0.8 ==  value){
+    } else if (0.8 ==  value) {
         return 4;
-    } else if (1.0 ==  value){
+    } else if (1.0 ==  value) {
         return 5;
     } else {
         return 5;
