@@ -84,8 +84,10 @@ public:
     int get_plugin_type() Q_DECL_OVERRIDE;
     QWidget * get_plugin_ui() Q_DECL_OVERRIDE;
     void plugin_delay_control() Q_DECL_OVERRIDE;
+    const QString name() const  Q_DECL_OVERRIDE;
 
 public:
+    void initSearchText();
     void setupComponent();
     void setupConnect();
     void initBgFormStatus();
@@ -131,8 +133,8 @@ private:
 
     QMap<QString, QListWidgetItem*> picWpItemMap;
 
-private:
     bool settingsCreate;
+    bool mFirstLoad;
 
 public slots:
     void resetDefaultWallpaperSlot();
