@@ -59,7 +59,14 @@ void Update::plugin_delay_control(){
 
 }
 
+const QString Update::name() const {
+
+    return QStringLiteral("update");
+}
+
 void Update::ui_init(){
+    //~ contents_path /update/System Update
+    ui->titleLabel->setText(tr("System Update"));
     ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
 
     QString filename = QDir::homePath() + "/.config/ukccUpdate.conf";
