@@ -19,8 +19,10 @@
  */
 #include "addautoboot.h"
 #include "ui_addautoboot.h"
+#include "CloseButton/closebutton.h"
 
 #include <QDebug>
+#include <QFileInfo>
 
 //#define DESKTOPPATH "/etc/xdg/autostart/"
 #define DESKTOPPATH "/usr/share/applications/"
@@ -29,60 +31,17 @@ extern void qt_blurImage(QImage &blurImage, qreal radius, bool quality, int tran
 
 AddAutoBoot::AddAutoBoot(QWidget *parent) :
     QDialog(parent),
-    ui(new Ui::AddAutoBoot)
-{
+    ui(new Ui::AddAutoBoot) {
+
     ui->setupUi(this);
     setWindowFlags(Qt::FramelessWindowHint | Qt::Tool);
     setAttribute(Qt::WA_TranslucentBackground);
 
-    ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
-
-    selectFile = "";
-
-//    ui->frame->setStyleSheet("QFrame{background: #ffffff; border: none; border-radius: 6px;}");
-
-//    //关闭按钮在右上角，窗体radius 6px，所以按钮只得6px
-//    ui->closeBtn->setStyleSheet("QPushButton#closeBtn{background: #ffffff; border: none; border-radius: 6px;}"
-//                                "QPushButton:hover:!pressed#closeBtn{background: #FA6056; border: none; border-top-left-radius: 2px; border-top-right-radius: 6px; border-bottom-left-radius: 2px; border-bottom-right-radius: 2px;}"
-//                                "QPushButton:hover:pressed#closeBtn{background: #E54A50; border: none; border-top-left-radius: 2px; border-top-right-radius: 6px; border-bottom-left-radius: 2px; border-bottom-right-radius: 2px;}");
-
-//    QString lineEditQss = QString("QLineEdit{background: #E9E9E9; border: none; border-radius: 4px;}");
-//    ui->nameLineEdit->setStyleSheet(lineEditQss);
-//    ui->execLineEdit->setStyleSheet(lineEditQss);
-//    ui->commentLineEdit->setStyleSheet(lineEditQss);
-
-//    QString btnQss = QString("QPushButton{background: #E9E9E9; border-radius: 4px;}"
-//                             "QPushButton:checked{background: #3d6be5; border-radius: 4px;}"
-//                             "QPushButton:hover:!pressed{background: #3d6be5; border-radius: 4px;}"
-//                             "QPushButton:hover:pressed{background: #415FC4; border-radius: 4px;}");
-
-//    ui->cancelBtn->setStyleSheet(btnQss);
-//    ui->certainBtn->setStyleSheet(btnQss);
-
-    ui->closeBtn->setIcon(QIcon("://img/titlebar/close.svg"));
-    ui->closeBtn->setProperty("useIconHighlightEffect", true);
-    ui->closeBtn->setProperty("iconHighlightEffectMode", 1);
-    ui->closeBtn->setFlat(true);
-
-    ui->closeBtn->setStyleSheet("QPushButton:hover:!pressed#closeBtn{background: #FA6056; border-radius: 4px;}"
-                                "QPushButton:hover:pressed#closeBtn{background: #E54A50; border-radius: 4px;}");
-
-
-    connect(ui->openBtn, SIGNAL(clicked(bool)), this, SLOT(open_desktop_dir_slots()));
-    connect(ui->cancelBtn, SIGNAL(clicked(bool)), this, SLOT(close()));
-    connect(ui->cancelBtn, &QPushButton::clicked, [=]{
-        resetBeforeClose();
-    });
-    connect(ui->certainBtn, &QPushButton::clicked, this, [=]{
-        emit autoboot_adding_signals(selectFile, ui->nameLineEdit->text(), ui->execLineEdit->text(), ui->commentLineEdit->text());
-        resetBeforeClose();
-    });
-    connect(ui->closeBtn, &QPushButton::clicked, [=]{
-        resetBeforeClose();
-    });
+    initStyle();
+    initConnection();
 }
 
-void AddAutoBoot::resetBeforeClose(){
+void AddAutoBoot::resetBeforeClose() {
     ui->nameLineEdit->setText(QString());
     ui->commentLineEdit->setText(QString());
     ui->execLineEdit->setText(QString());
@@ -103,6 +62,7 @@ void AddAutoBoot::paintEvent(QPaintEvent *event) {
     pixmapPainter.setRenderHint(QPainter::Antialiasing);
     pixmapPainter.setPen(Qt::transparent);
     pixmapPainter.setBrush(Qt::black);
+    pixmapPainter.setOpacity(0.65);
     pixmapPainter.drawPath(rectPath);
     pixmapPainter.end();
 
@@ -126,16 +86,47 @@ void AddAutoBoot::paintEvent(QPaintEvent *event) {
     p.save();
     p.fillPath(rectPath,palette().color(QPalette::Base));
     p.restore();
-
-
 }
 
-AddAutoBoot::~AddAutoBoot()
-{
+void AddAutoBoot::initStyle() {
+    ui->titleLabel->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
+
+    selectFile = "";
+
+    ui->closeBtn->setIcon(QIcon("://img/titlebar/close.svg"));
+
+    ui->nameLineEdit->setPlaceholderText(tr("Program name"));
+    ui->execLineEdit->setPlaceholderText(tr("Program exec"));
+    ui->commentLineEdit->setPlaceholderText(tr("Program comment"));
+
+    ui->hintLabel->setAlignment(Qt::AlignCenter);
+    ui->hintLabel->setStyleSheet("color:red;");
+    ui->certainBtn->setEnabled(false);
+}
+
+void AddAutoBoot::initConnection() {
+
+    connect(ui->openBtn, SIGNAL(clicked(bool)), this, SLOT(open_desktop_dir_slots()));
+    connect(ui->cancelBtn, SIGNAL(clicked(bool)), this, SLOT(close()));
+    connect(ui->execLineEdit, SIGNAL(textEdited(QString)), this, SLOT(execLinEditSlot(QString)));
+
+    connect(ui->cancelBtn, &QPushButton::clicked, [=] {
+        resetBeforeClose();
+    });
+    connect(ui->certainBtn, &QPushButton::clicked, this, [=] {
+        emit autoboot_adding_signals(selectFile, ui->nameLineEdit->text(), mDesktopExec, ui->commentLineEdit->text(), mDesktopIcon);
+        resetBeforeClose();
+    });
+    connect(ui->closeBtn, &CloseButton::clicked, [=] {
+        resetBeforeClose();
+    });
+}
+
+AddAutoBoot::~AddAutoBoot() {
     delete ui;
 }
 
-void AddAutoBoot::open_desktop_dir_slots(){
+void AddAutoBoot::open_desktop_dir_slots() {
     QString filters = "Desktop files(*.desktop)";
     QFileDialog fd;
     fd.setDirectory(DESKTOPPATH);
@@ -144,7 +135,8 @@ void AddAutoBoot::open_desktop_dir_slots(){
     fd.setNameFilter(filters);
     fd.setFileMode(QFileDialog::ExistingFile);
     fd.setWindowTitle(tr("select autoboot desktop"));
-    fd.setLabelText(QFileDialog::Accept, "Select");
+    fd.setLabelText(QFileDialog::Accept, tr("Select"));
+    fd.setLabelText(QFileDialog::Reject, tr("Cancel"));
 
     if (fd.exec() != QDialog::Accepted)
         return;
@@ -158,7 +150,7 @@ void AddAutoBoot::open_desktop_dir_slots(){
 
     //解析desktop文件
     GKeyFile * keyfile;
-    char *name, * comment, * exec;
+    char *name, * comment;
 
     keyfile = g_key_file_new();
     if (!g_key_file_load_from_file(keyfile, ba.data(), G_KEY_FILE_NONE, NULL)){
@@ -168,14 +160,52 @@ void AddAutoBoot::open_desktop_dir_slots(){
 
     name = g_key_file_get_locale_string(keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_NAME, NULL, NULL);
     comment = g_key_file_get_locale_string(keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_COMMENT, NULL, NULL);
-    exec = g_key_file_get_string(keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_EXEC, NULL);
+    mDesktopExec = g_key_file_get_string(keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_EXEC, NULL);
+    mDesktopIcon = g_key_file_get_string(keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_ICON, NULL);
 
-//    if (ui->nameLineEdit->text().isEmpty())
-        ui->nameLineEdit->setText(QString(name));
-//    if (ui->execLineEdit->text().isEmpty())
-        ui->execLineEdit->setText(QString(exec));
-//    if (ui->commentLineEdit->text().isEmpty())
-        ui->commentLineEdit->setText(QString(comment));
+    ui->nameLineEdit->setText(QString(name));
+    ui->execLineEdit->setText(QString(selectedfile));
+    ui->commentLineEdit->setText(QString(comment));
 
+    emit ui->execLineEdit->textEdited(QString(selectedfile));
     g_key_file_free(keyfile);
 }
+
+void AddAutoBoot::execLinEditSlot(const QString &fileName) {
+
+    selectFile = fileName;
+    QFileInfo fileInfo(fileName);
+    if (fileInfo.isFile() && fileName.endsWith("desktop")) {
+        ui->hintLabel->clear();
+        ui->certainBtn->setEnabled(true);
+
+        QByteArray ba;
+        ba = fileName.toUtf8();
+
+        //解析desktop文件
+        GKeyFile * keyfile;
+        char *name, * comment;
+
+        keyfile = g_key_file_new();
+        if (!g_key_file_load_from_file(keyfile, ba.data(), G_KEY_FILE_NONE, NULL)){
+            g_key_file_free (keyfile);
+            return;
+        }
+
+        name = g_key_file_get_locale_string(keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_NAME, NULL, NULL);
+        mDesktopExec = g_key_file_get_string(keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_EXEC, NULL);
+        mDesktopIcon = g_key_file_get_string(keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_ICON, NULL);
+        comment = g_key_file_get_locale_string(keyfile, G_KEY_FILE_DESKTOP_GROUP, G_KEY_FILE_DESKTOP_KEY_COMMENT, NULL, NULL);
+
+        ui->nameLineEdit->setText(QString(name));
+        ui->execLineEdit->setText(QString(fileName));
+        ui->commentLineEdit->setText(QString(comment));
+
+        g_key_file_free(keyfile);
+    } else {
+        ui->hintLabel->setText(tr("desktop file not exist"));
+        ui->hintLabel->setAlignment(Qt::AlignCenter);
+        ui->hintLabel->setStyleSheet("color:red;");
+        ui->certainBtn->setEnabled(false);
+    }
+}
