@@ -278,7 +278,7 @@ int QMLOutput::outputX() const
 
 void QMLOutput::setOutputX(int x)
 {
-    //qDebug()<<"setOutputX--->"<<x<<endl;
+//    qDebug()<<"setOutputX--->"<<x<<endl;
     if (m_output->pos().rx() == x) {
         return;
     }
@@ -297,7 +297,7 @@ int QMLOutput::outputY() const
 
 void QMLOutput::setOutputY(int y)
 {
-    //qDebug()<<"setOutputY--->"<<y<<endl;
+//    qDebug()<<"setOutputY--->"<<y<<endl;
     if (m_output->pos().ry() == y) {
         return;
     }
@@ -385,7 +385,6 @@ bool QMLOutput::collidesWithOutput(QObject *other)
 
 bool QMLOutput::maybeSnapTo(QMLOutput *other)
 {
-    //qDebug()<<"maybeSnapTo---->"<<endl;
     qreal centerX = x() + (width() / 2.0);
     qreal centerY = y() + (height() / 2.0);
 
@@ -539,13 +538,19 @@ bool QMLOutput::maybeSnapTo(QMLOutput *other)
 
         return true;
     }
-
+    if (!(this->output()->isConnected() && other->output()->isConnected())) {
+        if ((x() + width()) > 550) {
+            setPosition(QPointF(550 - width(), y()));
+        }
+        if ((y() + height()) > 300) {
+            setPosition(QPointF(x(), 350 - height()));
+        }
+    }
     return false;
 }
 
 void QMLOutput::moved()
 {
-    //qDebug()<<"moved----->"<<endl;
     const QList<QQuickItem*> siblings = screen()->childItems();
 
     // First, if we have moved, then unset the "cloneOf" flag
