@@ -45,14 +45,17 @@ public:
     int get_plugin_type() Q_DECL_OVERRIDE;
     QWidget * get_plugin_ui() Q_DECL_OVERRIDE;
     void plugin_delay_control() Q_DECL_OVERRIDE;
+    const QString name() const  Q_DECL_OVERRIDE;
 
-
+private:
+    void requestBackend();
 private:
     Ui::DisplayWindow * ui;
     QString pluginName;
     int pluginType;
     Widget * pluginWidget;
 
+    bool mFirstLoad;
 };
 
 #endif // DISPLAYSET_H
