@@ -1,7 +1,6 @@
 #include "outputconfig.h"
 #include "resolutionslider.h"
 #include "utils.h"
-//#include "kcm_screen_debug.h"
 
 #include <QStringBuilder>
 #include <QFormLayout>
@@ -12,7 +11,6 @@
 #include <QPushButton>
 #include <QGroupBox>
 
-//#include <KLocalizedString>
 #include <QComboBox>
 #include <QGSettings>
 
@@ -21,14 +19,8 @@
 
 #include "ComboBox/combobox.h"
 
-#define XSETTING_RENDERING_DPI "org.ukui.SettingsDaemon.plugins.xsettings"
-
-#define FONT_RENDERING_DPI "org.ukui.font-rendering"
-#define DPI_KEY "dpi"
-
-//#define SCRENN_SCALE_SCHMES "org.ukui.session"
-//#define GDK_SCALE_KEY "gdk-scale"
-
+#define SCALE_SCHEMAS "org.ukui.SettingsDaemon.plugins.xsettings"
+#define SCALE_KEY     "scaling-factor"
 
 OutputConfig::OutputConfig(QWidget *parent)
     : QWidget(parent)
@@ -61,84 +53,39 @@ void OutputConfig::initUi()
                 }
             });
 
-//    connect(mOutput.data(), &KScreen::Output::isEnabledChanged,
-//            this, [=]() {
-//                mEnabled->setChecked(mOutput->isEnabled());
-//            });
-
     connect(mOutput.data(), &KScreen::Output::rotationChanged,
             this, [=]() {
                 const int index = mRotation->findData(mOutput->rotation());
                 mRotation->setCurrentIndex(index);
             });
 
-//    connect(mOutput.data(), &KScreen::Output::scaleChanged,
-//            this, [=]() {
-//                const int index = mScale->findData(mOutput->scale());
-//                mScale->setCurrentIndex(index);
-//            });
-
-
     setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
 
     QVBoxLayout *vbox = new QVBoxLayout(this);
     vbox->setContentsMargins(0,0,0,0);
     vbox->setSpacing(2);
 
-    //注释显示器上方标签
-
-//    mTitle = new QLabel(this);
-//    mTitle->setAlignment(Qt::AlignHCenter);
-//    vbox->addWidget(mTitle);
-  //  setTitle(Utils::outputName(mOutput));
-
-    //QFormLayout *formLayout = new QFormLayout();
-
-
-
-//    mEnabled = new QCheckBox(i18n("已启用"), this);
-//    //mEnabled->setVisible(false);
-//    mEnabled->setChecked(mOutput->isEnabled());
-//    qDebug()<<"是否开启---->mEnable"<<mOutput<<endl;
-//    connect(mEnabled, &QCheckBox::clicked,
-//            this, [=](bool checked) {
-//                  //qDebug()<<"显示屏为---->mEnable"<<mOutput<<endl;
-//                  mOutput->setEnabled(checked);
-//                  qDebug() << "上层勾选---->"<<mOutput.data() << mOutput->name() << mOutput->isEnabled();
-//                  Q_EMIT changed();
-//            });
-//    formLayout->addRow(i18n("显示:"), mEnabled);
-
-//    mMonitor = new QComboBox(this);
-//    formLayout->addRow(i18n("主显示器"),mMonitor);
-
     //分辨率下拉框
     mResolution = new ResolutionSlider(mOutput, this);
-//    mResolution->setFont(ft);
     mResolution->setSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum);
     mResolution->setMinimumSize(402,30);
     mResolution->setMaximumSize(16777215,30);
 
 
     QLabel *resLabel = new QLabel(this);
+    //~ contents_path /display/resolution
     resLabel->setText(tr("resolution"));
-//    resLabel->setFont(ft);
     resLabel->setSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum);
     resLabel->setMinimumSize(118,30);
     resLabel->setMaximumSize(118,30);
 
     QHBoxLayout *resLayout = new QHBoxLayout();
-    //resLayout->setContentsMargins(0,5,0,5);
     resLayout->addWidget(resLabel);
     resLayout->addWidget(mResolution);
-//    resLayout->addStretch();
-
 
     QFrame *resFrame = new QFrame(this);
     resFrame->setFrameShape(QFrame::Shape::Box);
     resFrame->setLayout(resLayout);
-//    resWidget->setStyleSheet("background-color:#F4F4F4;border-radius:6px");
-//    mResolution->setStyleSheet("background-color:#F8F9F9");
 
     resFrame->setSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum);
     resFrame->setMinimumSize(552,50);
@@ -150,19 +97,14 @@ void OutputConfig::initUi()
             this, &OutputConfig::slotResolutionChanged);
 
     //方向下拉框
-    mRotation = new QComboBox();
-
-//    mRotation->setFont(ft);
+    mRotation = new QComboBox(this);
     mRotation->setSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum);
     mRotation->setMinimumSize(402,30);
     mRotation->setMaximumSize(16777215,30);
-//    mRotation->setStyleSheet(qss);
-//    mRotation->setItemDelegate(itemDelege);
 
-
-    QLabel *rotateLabel = new QLabel();
+    QLabel *rotateLabel = new QLabel(this);
+    // ~contents_path /display/orientation
     rotateLabel->setText(tr("orientation"));
-//    rotateLabel->setFont(ft);
     rotateLabel->setSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum);
     rotateLabel->setMinimumSize(118,30);
     rotateLabel->setMaximumSize(118,30);
@@ -170,15 +112,11 @@ void OutputConfig::initUi()
     QHBoxLayout *rotateLayout = new QHBoxLayout();
     rotateLayout->addWidget(rotateLabel);
 
-
     rotateLayout->addWidget(mRotation);
-//    rotateLayout->addStretch();
 
     QFrame *rotateFrame = new QFrame(this);
     rotateFrame->setFrameShape(QFrame::Shape::Box);
     rotateFrame->setLayout(rotateLayout);
-//    rotateWidget->setStyleSheet("background-color:#F4F4F4;border-radius:6px");
-//    mRotation->setStyleSheet("background-color:#F8F9F9");
 
     rotateFrame->setSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum);
     rotateFrame->setMinimumSize(550,50);
@@ -192,35 +130,16 @@ void OutputConfig::initUi()
             this, &OutputConfig::slotRotationChanged);
     mRotation->setCurrentIndex(mRotation->findData(mOutput->rotation()));
 
-    //formLayout->addRow(rotateLabel, mRotation);
     vbox->addWidget(rotateFrame);
 
-    //缩放暂时用不到
-//    if (!mShowScaleOption) {
-//        mScale = new QComboBox(this);
-//        mScale->addItem(i18nc("Scale multiplier, show everything at 1 times normal scale", "1x"), 1);
-//        mScale->addItem(i18nc("Scale multiplier, show everything at 2 times normal scale", "2x"), 2);
-//        connect(mScale, static_cast<void(QComboBox::*)(int)>(&QComboBox::activated),
-//                this, &OutputConfig::slotScaleChanged);
-//        mScale->setCurrentIndex(mScale->findData(mOutput->scale()));
-//        formLayout->addRow(i18n("缩放:"), mScale);
-//        formLayout->addItem(new QSpacerItem(1, 1, QSizePolicy::Expanding, QSizePolicy::Minimum));
-//    }
-
-
     //刷新率下拉框
-    mRefreshRate = new QComboBox();
-//    mRefreshRate->setFont(ft);
-//    mRefreshRate->setSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum);
+    mRefreshRate = new QComboBox(this);
     mRefreshRate->setMinimumSize(402,30);
     mRefreshRate->setMaximumSize(16777215,30);
-//    mRefreshRate->setStyleSheet(qss);
-//    mRefreshRate->setItemDelegate(itemDelege);
-//    mRefreshRate->setMaxVisibleItems(5);
 
-    QLabel *freshLabel = new QLabel();
+    QLabel *freshLabel = new QLabel(this);
+    // ~contents_path /display/refresh rate
     freshLabel->setText(tr("refresh rate"));
-//    freshLabel->setFont(ft);
     freshLabel->setSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum);
     freshLabel->setMinimumSize(118,30);
     freshLabel->setMaximumSize(118,30);
@@ -228,12 +147,10 @@ void OutputConfig::initUi()
     QHBoxLayout *freshLayout = new QHBoxLayout();
     freshLayout->addWidget(freshLabel);
     freshLayout->addWidget(mRefreshRate);
-//    freshLayout->addStretch();
 
     QFrame *freshFrame = new QFrame(this);
     freshFrame->setFrameShape(QFrame::Shape::Box);
     freshFrame->setLayout(freshLayout);
-//    freshWidget->setStyleSheet("background-color:#F4F4F4;border-radius:6px");
 
     freshFrame->setSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum);
     freshFrame->setMinimumSize(550,50);
@@ -246,34 +163,20 @@ void OutputConfig::initUi()
     connect(mRefreshRate, static_cast<void(QComboBox::*)(int)>(&QComboBox::activated),
             this, &OutputConfig::slotRefreshRateChanged);
 
-
-
-    scaleCombox = new QComboBox();
-//    mRefreshRate->setSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum);
+    scaleCombox = new QComboBox(this);
+    scaleCombox->setObjectName("scaleCombox");
     scaleCombox->setMinimumSize(402,30);
     scaleCombox->setMaximumSize(16777215,30);
 
-
-
     int maxReslu = mResolution->getMaxResolution().width();
 
-#if QT_VERSION < QT_VERSION_CHECK(5,7,0)
+    scaleCombox->addItem(tr("100%"));
     if (maxReslu >= 2000) {
         scaleCombox->addItem(tr("200%"));
-    } else {
-        scaleCombox->addItem(tr("100%"));
     }
-#else
-    scaleCombox->addItem(tr("100%"));
-    if (maxReslu >= 2000 && maxReslu <= 3800) {
-        scaleCombox->addItem(tr("200%"));
-    } else if (maxReslu >= 3800 || maxReslu >= 4000) {
-        scaleCombox->addItem(tr("200%"));
-        scaleCombox->addItem(tr("300%"));
-    }
-#endif
 
-    QLabel *scaleLabel = new QLabel();
+    QLabel *scaleLabel = new QLabel(this);
+    //~ contents_path /display/screen zoom
     scaleLabel->setText(tr("screen zoom"));
     scaleLabel->setSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum);
     scaleLabel->setMinimumSize(118,30);
@@ -282,54 +185,35 @@ void OutputConfig::initUi()
     QHBoxLayout *scaleLayout = new QHBoxLayout();
     scaleLayout->addWidget(scaleLabel);
     scaleLayout->addWidget(scaleCombox);
-//    freshLayout->addStretch();
 
     QFrame *scaleFrame = new QFrame(this);
     scaleFrame->setFrameShape(QFrame::Shape::Box);
     scaleFrame->setLayout(scaleLayout);
-//    scaleWidget->setStyleSheet("background-color:#F4F4F4;border-radius:6px");
 
     scaleFrame->setSizePolicy(QSizePolicy::Minimum,QSizePolicy::Minimum);
     scaleFrame->setMinimumSize(550,50);
     scaleFrame->setMaximumSize(960,50);
     vbox->addWidget(scaleFrame);
-    scaleFrame->setVisible(isSupportDPI());
 
     int scale = getScreenScale();
-#if QT_VERSION < QT_VERSION_CHECK(5,7,0)
 
-#else
     scaleCombox->setCurrentIndex(0);
     if (scale <= scaleCombox->count() && scale > 0) {
-//        qDebug()<<"scale is----->"<<scale<<endl;
         scaleCombox->setCurrentIndex(scale - 1);
     }
     slotScaleChanged(scale - 1);
-#endif
 
-    connect(scaleCombox, static_cast<void(QComboBox::*)(int)>(&QComboBox::activated),
+    connect(scaleCombox, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
             this, &OutputConfig::slotScaleChanged);
 }
 
-int OutputConfig::getMaxReslotion() {
-
-}
-
 int OutputConfig::getScreenScale() {
-    QGSettings * dpiSettings;
-    QByteArray id(FONT_RENDERING_DPI);
-    int scale = 0;
-    if (QGSettings::isSchemaInstalled(FONT_RENDERING_DPI)) {
-        dpiSettings = new QGSettings(id);
-        scale = dpiSettings->get(DPI_KEY).toInt();
-        if (96 == scale)  {
-            scale = 1;
-        } else if (192 == scale) {
-            scale = 2;
-        } else if (288 == scale) {
-            scale = 3;
-        } else {
-            scale = 1;
+    QByteArray id(SCALE_SCHEMAS);
+    int scale = 1;
+    if (QGSettings::isSchemaInstalled(SCALE_SCHEMAS)) {
+        QGSettings dpiSettings(id);
+        if (dpiSettings.keys().contains("scalingFactor")) {
+            scale = dpiSettings.get(SCALE_KEY).toInt();
         }
     }
     return scale;
@@ -355,13 +239,12 @@ void OutputConfig::slotResolutionChanged(const QSize &size)
     }
 
     KScreen::ModePtr selectedMode;
+    KScreen::ModePtr currentMode  = mOutput->currentMode();
     QList<KScreen::ModePtr> modes;
     Q_FOREACH (const KScreen::ModePtr &mode, mOutput->modes()) {
         if (mode->size() == size) {
+            selectedMode = mode;
             modes << mode;
-            if (!selectedMode || selectedMode->refreshRate() < mode->refreshRate()) {
-                selectedMode = mode;
-            }
         }
     }
 
@@ -370,8 +253,8 @@ void OutputConfig::slotResolutionChanged(const QSize &size)
 
     // Don't remove the first "Auto" item - prevents ugly flicker of the combobox
     // when changing resolution
-    for (int i = 1; i < mRefreshRate->count(); ++i) {
-        mRefreshRate->removeItem(i);
+    for (int i = mRefreshRate->count(); i >= 2; --i) {
+        mRefreshRate->removeItem(i - 1);
     }
 
     for (int i = 0, total = modes.count(); i < total; ++i) {
@@ -380,7 +263,7 @@ void OutputConfig::slotResolutionChanged(const QSize &size)
         // If selected refresh rate is other then what we consider the "Auto" value
         // - that is it's not the highest resolution - then select it, otherwise
         // we stick with "Auto"
-        if (mode == selectedMode && i > 1) {
+        if (mode == currentMode && mRefreshRate->count() > 1) {
             // i + 1 since 0 is auto
             mRefreshRate->setCurrentIndex(i + 1);
         }
@@ -409,6 +292,7 @@ void OutputConfig::slotRefreshRateChanged(int index)
     } else {
         modeId = mRefreshRate->itemData(index).toString();
     }
+    qDebug()  << "modeId is:" << modeId << endl;
     mOutput->setCurrentModeId(modeId);
 
     Q_EMIT changed();
@@ -416,8 +300,6 @@ void OutputConfig::slotRefreshRateChanged(int index)
 
 void OutputConfig::slotScaleChanged(int index)
 {
-//    auto scale = mScale->itemData(index).toInt();
-//    mOutput->setScale(scale);
     Q_EMIT scaleChanged(index);
 }
 
@@ -460,35 +342,3 @@ QStringList OutputConfig::readFile(const QString& filepath) {
     }
 }
 
-int OutputConfig::scaleRet() {
-    QGSettings * dpiSettings;
-    QByteArray id(FONT_RENDERING_DPI);
-    int scale = 0;
-    if (QGSettings::isSchemaInstalled(FONT_RENDERING_DPI)) {
-        dpiSettings = new QGSettings(id);
-        scale = dpiSettings->get(DPI_KEY).toInt();
-        if (96 == scale)  {
-            scale = 1;
-        } else if (192 == scale) {
-            scale = 2;
-        } else if (288 == scale) {
-            scale = 3;
-        } else {
-            scale = 1;
-        }
-    }
-    return scale;
-}
-
-bool OutputConfig::isSupportDPI() {
-    const QByteArray id(XSETTING_RENDERING_DPI);
-
-    if (QGSettings::isSchemaInstalled(id)) {
-        QGSettings dpiSetting(id);
-        QStringList keys = dpiSetting.keys();
-        if (keys.contains("scalingFactor")) {
-            return true;
-        }
-    }
-    return false;
-}
