@@ -8,13 +8,10 @@
 #include <QFile>
 #include <QStyledItemDelegate>
 
-//#include <KLocalizedString>
-
 #include <KF5/KScreen/kscreen/output.h>
 
 static bool sizeLessThan(const QSize &sizeA, const QSize &sizeB)
 {
-
     return sizeA.width() * sizeA.height() < sizeB.width() * sizeB.height();
 }
 
@@ -22,6 +19,8 @@ ResolutionSlider::ResolutionSlider(const KScreen::OutputPtr &output, QWidget *pa
     : QWidget(parent)
     , mOutput(output)
 {
+    mExcludeModes.push_back(QSize(1152, 864));
+
     connect(output.data(), &KScreen::Output::currentModeIdChanged,
             this, &ResolutionSlider::slotOutputModeChanged);
 #if QT_VERSION <= QT_VERSION_CHECK(5, 12, 0)
@@ -72,16 +71,11 @@ void ResolutionSlider::init()
         mComboBox = new QComboBox();
         mComboBox->setMinimumSize(402,30);
         mComboBox->setMaximumSize(1677215, 30);
-//        mComboBox->setSizeAdjustPolicy(QComboBox::AdjustToContents);
-//        mComboBox->setEditable(false);
-//        mComboBox->setStyleSheet(qss);
-//        mComboBox->setItemDelegate(itemDelege);
-//        mComboBox->setMaxVisibleItems(5);
 
         int currentModeIndex = -1;
         int preferredModeIndex = -1;
         Q_FOREACH (const QSize &size, mModes) {
-            if (size.width() < 1024) {
+            if (size.width() * size.height() < 1024 * 576 || mExcludeModes.contains(size)) {
                 continue;
             }
             if (size == mModes[0]) {
