@@ -29,12 +29,13 @@
 
 #include "shell/interface.h"
 
+#include "commonComponent/ComboxFrame/comboxframe.h"
+
 namespace Ui {
 class Power;
 }
 
-class Power : public QObject, CommonInterface
-{
+class Power : public QObject, CommonInterface {
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.kycc.CommonInterface")
     Q_INTERFACES(CommonInterface)
@@ -44,13 +45,14 @@ public:
     ~Power();
 
 public:
-    QString get_plugin_name() Q_DECL_OVERRIDE;
-    int get_plugin_type() Q_DECL_OVERRIDE;
-    QWidget * get_plugin_ui() Q_DECL_OVERRIDE;
+    QString get_plugin_name()   Q_DECL_OVERRIDE;
+    int get_plugin_type()       Q_DECL_OVERRIDE;
+    QWidget * get_plugin_ui()   Q_DECL_OVERRIDE;
     void plugin_delay_control() Q_DECL_OVERRIDE;
+    const QString name() const  Q_DECL_OVERRIDE;
 
 public:
-    void setupStylesheet();
+    void initSearText();
     void setupComponent();
     void setupConnect();
     void initModeStatus();
@@ -58,17 +60,17 @@ public:
     void resetCustomPlanStatus();
     void initPowerOtherStatus();
     void isPowerSupply();
-
     void refreshUI();
+    int  getIdleTime();
 
 private:
     Ui::Power *ui;
 
-private:
     QWidget * pluginWidget;
 
-private:
-    QGSettings * settings;
+    QGSettings *settings;
+    QGSettings *sessionSetting;
+    QGSettings *mUkccpersonpersonalize;
 
     QString pluginName;
     int pluginType;
@@ -81,8 +83,27 @@ private:
     QStringList buttonStringList;
     QStringList iconShowList;
 
-private:
+    QStringList mPowerKeys;
+
     bool settingsCreate;
+    bool isExitsPower;
+    bool mFirstLoad;
+
+    ComboxFrame *mHibernate;
+    ComboxFrame *mPowerBtn;
+    ComboxFrame *mBatteryAct;
+
+    QDBusInterface *mUkccInterface;
+
+private:
+    void initGeneralSet();
+    bool getHibernateStatus();
+    QString  getHibernateTime();
+    void initDbus();
+
+private slots:
+    void setIdleTime(int idleTime);
+    void setHibernateTime(QString hibernate);
 };
 
 #endif // POWER_H
