@@ -35,18 +35,11 @@
 #define DATE_FORMATE_KEY "date"
 #define TIME_KEY         "hoursystem"
 
-const QVector<QString> CFormats{"zh_SG.UTF-8", "zh_CN.UTF-8", "lt_LT.UTF-8", "en_ZW.UTF-8", "en_ZM.UTF-8",
-                               "en_ZA.UTF-8", "en_US.UTF-8", "en_SG.UTF-8", "en_PH.UTF-8", "en_NZ.UTF-8",
-                               "en_NG.UTF-8", "en_IN.UTF-8", "en_IL.UTF-8", "en_IE.UTF-8", "en_HK.UTF-8",
-                               "en_GB.UTF-8", "en_DK.UTF-8", "en_CA.UTF-8", "en_BW.UTF-8", "en_AU.UTF-8",
-                               "en_AG.UTF-8", "af_ZA.UTF-8"};
-
 Area::Area()
 {
     ui = new Ui::Area;
     pluginWidget = new QWidget;
     pluginWidget->setAttribute(Qt::WA_DeleteOnClose);
-//    pluginWidget->setStyleSheet("background: #ffffff;");
     ui->setupUi(pluginWidget);
 
     pluginName = tr("Area");
@@ -56,17 +49,21 @@ Area::Area()
     ui->title2Label->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
     ui->title3Label->setStyleSheet("QLabel{font-size: 18px; color: palette(windowText);}");
 
+    ui->countrylabel->adjustSize();
+    ui->languagelabel->adjustSize();
+    ui->formframe->adjustSize();
 
     const QByteArray id(PANEL_GSCHEMAL);
 
     if(QGSettings::isSchemaInstalled(id)) {
-        m_gsettings = new QGSettings(id);
-        //  监听key的value是否发生了变化
-        /*
-        connect(m_gsettings, &QGSettings::changed, this, [=] (const QString &key) {
-            initFormatData();
+        m_gsettings = new QGSettings(id, QByteArray(), pluginWidget);
+        mDateFormat = m_gsettings->get(DATE_FORMATE_KEY).toString();
+        connect(m_gsettings, &QGSettings::changed, this, [=](QString key) {
+            mDateFormat = m_gsettings->get(DATE_FORMATE_KEY).toString();
+            if ("hoursystem" == key) {
+                initFormatData();
+            }
         });
-        */
     }
 
     unsigned int uid = getuid();
@@ -80,25 +77,19 @@ Area::Area()
 
     m_itimer = new QTimer();
     m_itimer->start(1000);
-    connect(m_itimer,SIGNAL(timeout()), this, SLOT(datetime_update_slot()));
 
     initUI();
     initComponent();
+    connectToServer();
+
+    connect(m_itimer,SIGNAL(timeout()), this, SLOT(datetime_update_slot()));
     connect(ui->langcomboBox,SIGNAL(currentIndexChanged(int)),this,SLOT(change_language_slot(int)));
     connect(ui->countrycomboBox,SIGNAL(currentIndexChanged(int)),this,SLOT(change_area_slot(int)));
-//    connect(ui->addlanBtn, SIGNAL(clicked()), this, SLOT(add_lan_btn_slot()));
     connect(ui->chgformButton,SIGNAL(clicked()),this,SLOT(changeform_slot()));
-
-//    connect(ui->langcomboBox, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
-//            [=]{
-//        KMessageBox::information(ui->languageframe, tr("Need to cancel to take effect"));
-//    });
-
     connect(ui->countrycomboBox, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged),
             [=]{
         KMessageBox::information(ui->languageframe_2, tr("Need to log off to take effect"));
     });
-
 }
 
 Area::~Area()
@@ -107,38 +98,69 @@ Area::~Area()
     delete m_itimer;
 }
 
-QString Area::get_plugin_name(){
+void Area::cloudChangedSlot(const QString &key) {
+    if(key == "area") {
+        initComponent();
+    }
+}
+
+void Area::connectToServer(){
+    cloudInterface = new QDBusInterface("org.kylinssoclient.dbus",
+                                          "/org/kylinssoclient/path",
+                                          "org.freedesktop.kylinssoclient.interface",
+                                          QDBusConnection::sessionBus());
+    if (!cloudInterface->isValid())
+    {
+        qDebug() << "fail to connect to service";
+        qDebug() << qPrintable(QDBusConnection::systemBus().lastError().message());
+        return;
+    }
+//    QDBusConnection::sessionBus().connect(cloudInterface, SIGNAL(shortcutChanged()), this, SLOT(shortcutChangedSlot()));
+    QDBusConnection::sessionBus().connect(QString(), QString("/org/kylinssoclient/path"), QString("org.freedesktop.kylinssoclient.interface"), "keyChanged", this, SLOT(cloudChangedSlot(QString)));
+    // 将以后所有DBus调用的超时设置为 milliseconds
+    cloudInterface->setTimeout(2147483647); // -1 为默认的25s超时
+}
+
+QString Area::get_plugin_name() {
     return pluginName;
 }
 
-int Area::get_plugin_type(){
+int Area::get_plugin_type() {
     return pluginType;
 }
 
-QWidget *Area::get_plugin_ui(){
+QWidget *Area::get_plugin_ui() {
     return pluginWidget;
 }
 
-void Area::plugin_delay_control(){
+void Area::plugin_delay_control() {
 
 }
 
-void Area::run_external_app_slot(){
+const QString Area::name() const {
+    return QStringLiteral("area");
+
+}
+
+void Area::run_external_app_slot() {
     QString cmd = "gnome-language-selector";
 
     QProcess process(this);
     process.startDetached(cmd);
 }
 
-void Area::initUI(){
+void Area::initUI() {
+    //~ contents_path /area/current area
     ui->titleLabel->setText(tr("current area"));
     ui->countrylabel->setText(tr("display format area"));
+    //~ contents_path /area/format of area
     ui->title2Label->setText(tr("format of area"));
     ui->calendarlabel->setText(tr("calendar"));
     ui->weeklabel->setText(tr("first day of week"));
     ui->datelabel->setText(tr("date"));
     ui->timelabel->setText(tr("time"));
     ui->chgformButton->setText(tr("change format of data"));
+    //~ contents_path /area/first language
     ui->title3Label->setText(tr("first language"));
     ui->languagelabel->setText(tr("system language"));
 
@@ -165,20 +187,23 @@ void Area::initUI(){
     addWgt->setLayout(addLyt);
 
     // 悬浮改变Widget状态
-    connect(addWgt, &HoverWidget::enterWidget, this, [=](QString mname){
+    connect(addWgt, &HoverWidget::enterWidget, this, [=](QString mname) {
+        Q_UNUSED(mname);
         QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "white", 12);
         iconLabel->setPixmap(pixgray);
         textLabel->setStyleSheet("color: palette(base);");
 
     });
     // 还原状态
-    connect(addWgt, &HoverWidget::leaveWidget, this, [=](QString mname){
+    connect(addWgt, &HoverWidget::leaveWidget, this, [=](QString mname) {
+        Q_UNUSED(mname);
         QPixmap pixgray = ImageUtil::loadSvg(":/img/titlebar/add.svg", "black", 12);
         iconLabel->setPixmap(pixgray);
         textLabel->setStyleSheet("color: palette(windowText);");
     });
 
-    connect(addWgt, &HoverWidget::widgetClicked, this, [=](QString mname){
+    connect(addWgt, &HoverWidget::widgetClicked, this, [=](QString mname) {
+        Q_UNUSED(mname);
         add_lan_btn_slot();
     });
 
@@ -188,8 +213,8 @@ void Area::initUI(){
 void Area::initComponent() {
     QStringList res = getUserDefaultLanguage();
     QString lang = res.at(1);
-    int langIndex = lang.split(':').at(0) == "en_US" ? 0 : 1;;
-    int formatIndex = res.at(0) == "en_US.UTF-8" ? 0 : 1;
+    int langIndex = lang.split(':').at(0) == "zh_CN" ? 1 : 0;
+    int formatIndex = res.at(0) == "zh_CN.UTF-8" ? 1 : 0;
     ui->langcomboBox->setCurrentIndex(langIndex);
     ui->countrycomboBox->setCurrentIndex(formatIndex);
 
@@ -228,8 +253,7 @@ void Area::initFormatData() {
 
     QDateTime current = QDateTime::currentDateTime();
     QString currentsecStr  ;
-    QString dateFormat = m_gsettings->get(DATE_FORMATE_KEY).toString();
-    if ("cn" == dateFormat) {
+    if ("cn" == mDateFormat) {
        currentsecStr = current.toString("yyyy/MM/dd ");;
     } else {
        currentsecStr = current.toString("yyyy-MM-dd ");
@@ -239,7 +263,7 @@ void Area::initFormatData() {
     this->hourformat = m_gsettings->get(TIME_KEY).toString();
 }
 
-void Area::change_language_slot(int index){
+void Area::change_language_slot(int index) {
     QDBusReply<bool> res;
     switch (index) {
     case 0:
@@ -249,11 +273,11 @@ void Area::change_language_slot(int index){
         res = m_areaInterface->call("SetLanguage","zh_CN");
         break;
     }
-    ui->countrycomboBox->setCurrentIndex(index);
+
+    KMessageBox::information(ui->languageframe, tr("Need to log off to take effect"));
 }
 
-void Area::change_area_slot(int index){
-    qDebug()<<"area----------->"<<endl;
+void Area::change_area_slot(int index) {
     QDBusReply<bool> res;
     switch (index) {
     case 0:
@@ -275,6 +299,14 @@ void Area::datetime_update_slot() {
         timeStr = current.toString("AP hh: mm : ss");
     }
     ui->timelabelshow->setText(timeStr);
+
+    QString currentsecStr;
+    if ("cn" == mDateFormat) {
+       currentsecStr = current.toString("yyyy/MM/dd ");;
+    } else {
+       currentsecStr = current.toString("yyyy-MM-dd ");
+    }
+    ui->datelabelshow->setText(currentsecStr);
 }
 
 void Area::add_lan_btn_slot() {
@@ -285,11 +317,11 @@ void Area::add_lan_btn_slot() {
 }
 
 void Area::changeform_slot() {
-//    DataFormat *dialog = new DataFormat();
-//    connect(dialog, SIGNAL(dataChangedSignal()),this,SLOT(initFormatData()));
-//    dialog->setWindowTitle(tr("change data format"));
-//    dialog->setAttribute(Qt::WA_DeleteOnClose);
-//    dialog->exec();
+    DataFormat *dialog = new DataFormat();
+    connect(dialog, SIGNAL(dataChangedSignal()),this,SLOT(initFormatData()));
+    dialog->setWindowTitle(tr("change data format"));
+    dialog->setAttribute(Qt::WA_DeleteOnClose);
+    dialog->exec();
 }
 
 QStringList Area::readFile(const QString& filepath) {
@@ -315,34 +347,22 @@ QStringList Area::readFile(const QString& filepath) {
 }
 
 QStringList Area::getUserDefaultLanguage() {
-    int pos = 0;
     QString formats;
     QString language;
-    QStringList filestr;
     QStringList result;
-    QString fname = getenv("HOME");
-    fname += "/.pam_environment";
 
-    filestr = this->readFile(fname);
-//    qDebug()<<"result is------>"<<filestr<<endl;
-    QRegExp re("LANGUAGE(\t+DEFAULT)?=(.*)$");
-    for(int i = 0; i < filestr.length(); i++) {
-        while((pos = re.indexIn(filestr.at(i), pos)) != -1) {
-            language = re.cap(2);
-            pos += re.matchedLength();
-        }
-    }
-
-    QDBusInterface * iproperty = new QDBusInterface("org.freedesktop.Accounts",
-                                            objpath,
-                                            "org.freedesktop.DBus.Properties",
-                                            QDBusConnection::systemBus());
-    QDBusReply<QMap<QString, QVariant> > reply = iproperty->call("GetAll", "org.freedesktop.Accounts.User");
+    QDBusInterface iproperty("org.freedesktop.Accounts",
+                             objpath,
+                             "org.freedesktop.DBus.Properties",
+                             QDBusConnection::systemBus());
+    QDBusReply<QMap<QString, QVariant> > reply = iproperty.call("GetAll", "org.freedesktop.Accounts.User");
     if (reply.isValid()){
         QMap<QString, QVariant> propertyMap;
         propertyMap = reply.value();
-        formats = propertyMap.find("FormatsLocale").value().toString();
-        if(language.isEmpty()) {
+        if (propertyMap.keys().contains("FormatsLocale")) {
+            formats = propertyMap.find("FormatsLocale").value().toString();
+        }
+        if(language.isEmpty() && propertyMap.keys().contains("Language")) {
             language = propertyMap.find("Language").value().toString();
         }
     } else {
@@ -350,6 +370,5 @@ QStringList Area::getUserDefaultLanguage() {
     }
     result.append(formats);
     result.append(language);
-//    qDebug()<<"result is---------->"<<result<<endl;
     return result;
 }
