@@ -21,8 +21,6 @@
 #define DATETIME_H
 
 #include <QObject>
-#include <QtPlugin>
-
 
 #include "shell/interface.h"
 #include "changtime.h"
@@ -31,8 +29,6 @@
 #include <QLabel>
 #include <QAbstractButton>
 
-#include <QGSettings>
-
 #include <QDBusInterface>
 #include <QDBusConnection>
 #include <QDBusError>
@@ -42,12 +38,12 @@
 #include <QDateTime>
 #include <QTimer>
 #include <QSettings>
+#include <QGSettings>
 
 #include "worldMap/timezonechooser.h"
 #include "worldMap/zoneinfo.h"
 #include "SwitchButton/switchbutton.h"
 
-
 /* qt会将glib里的signals成员识别为宏，所以取消该宏
  * 后面如果用到signals时，使用Q_SIGNALS代替即可
  **/
@@ -60,7 +56,6 @@ extern "C" {
 #include <gio/gio.h>
 }
 
-
 #define TZ_DATA_FILE "/usr/share/zoneinfo/zoneUtc"
 #define DEFAULT_TZ "Asia/Shanghai"
 
@@ -82,30 +77,30 @@ public:
     int get_plugin_type() Q_DECL_OVERRIDE;
     QWidget * get_plugin_ui() Q_DECL_OVERRIDE;
     void plugin_delay_control() Q_DECL_OVERRIDE;
+    const QString name() const  Q_DECL_OVERRIDE;
 
     void component_init();
     void status_init();
+    void connectToServer();
 
     bool fileIsExits(const QString& filepath);
 
 private:
     Ui::DateTime *ui;
 
-
     QString pluginName;
     int pluginType;
     QWidget * pluginWidget;
 
     QGSettings * m_formatsettings  = nullptr;
 
-
     QDBusInterface *m_datetimeiface = nullptr;
     QDBusInterface *m_datetimeiproperties = nullptr;
+    QDBusInterface *m_cloudInterface;
 
     QMap<QString, int> tzindexMapEn;
     QMap<QString, int> tzindexMapCN;
 
-
     SwitchButton *m_formTimeBtn = nullptr;
     QLabel *m_formTimeLabel = nullptr;
     QTimer * m_itimer = nullptr;
@@ -115,8 +110,6 @@ private:
 
     QDateTime current;
 
-//    bool m_EFHour = true;//默认为24小时制
-
 Q_SIGNALS:
     void changed();
 
@@ -125,16 +118,16 @@ private slots:
     void changetime_slot();
     void changezone_slot();
     void changezone_slot(QString );
-    void time_format_clicked_slot(bool);
+    void time_format_clicked_slot(bool, bool);
     void rsync_with_network_slot();
     void showendLabel();
     void hidendLabel();
+    void keyChangedSlot(const QString &key);
 
 private:
     void loadHour();
     void connectGSetting();
     QString getLocalTimezoneName(QString timezone, QString locale);
-
 };
 
 #endif // DATETIME_H
