@@ -2,9 +2,9 @@
 #define TIMEZONECHOOSER_H
 
 #include "timezonemap.h"
-
 #include <QFrame>
 #include <QMap>
+#include <QWidget>
 #include <QLabel>
 #include <QPushButton>
 #include <QAbstractItemView>
@@ -13,7 +13,7 @@ class TimeZoneChooser : public QFrame
 {
     Q_OBJECT
 public:
-    explicit TimeZoneChooser();
+    explicit TimeZoneChooser(QWidget *parent);
     void setTitle();
 
 public slots:
@@ -26,7 +26,6 @@ Q_SIGNALS:
 protected:
     void keyRealeaseEvent(QKeyEvent* event);
     bool eventFilter(QObject* obj, QEvent* event);
-    void paintEvent(QPaintEvent *);
 
 private:
     QSize getFitSize();
@@ -38,14 +37,12 @@ private:
     QMap<QString, QString> m_zoneCompletion;
     QAbstractItemView      *m_popup;
 
-
     TimezoneMap* m_map;
     QLineEdit* m_searchInput;
     QLabel      *m_title;
     QPushButton *m_cancelBtn;
     QPushButton *m_confirmBtn;
-    QPushButton *closeBtn;
-
+    QPushButton *m_closeBtn;
 };
 
 #endif // TIMEZONECHOOSER_H
