@@ -28,19 +28,10 @@
 LeftWidgetItem::LeftWidgetItem(QWidget *parent) :
     QWidget(parent)
 {
-//    this->setStyleSheet("background: none;");
     widget = new QWidget(this);
-//    widget->setFixedSize(120, 40);
-//    widget->setStyleSheet("QWidget{background: #FFFFFF;}");
     widget->setFixedHeight(40);
 
-
     iconLabel = new QLabel(widget);
-    QSizePolicy policy = iconLabel->sizePolicy();
-    policy.setHorizontalPolicy(QSizePolicy::Fixed);
-    policy.setVerticalPolicy(QSizePolicy::Fixed);
-    iconLabel->setSizePolicy(policy);
-    iconLabel->setFixedSize(24, 24);
 
     textLabel = new QLabel(widget);
     QSizePolicy policy1 = textLabel->sizePolicy();
@@ -49,7 +40,6 @@ LeftWidgetItem::LeftWidgetItem(QWidget *parent) :
     textLabel->setSizePolicy(policy1);
     textLabel->setScaledContents(true);
 
-
     QHBoxLayout * mainlayout = new QHBoxLayout(widget);
     mainlayout->setSpacing(8);
     mainlayout->setContentsMargins(8, 0, 0, 0);
@@ -78,6 +68,7 @@ void LeftWidgetItem::setLabelPixmap(QString filename, QString icoName, QString c
     this->icoName = icoName;
 
     QPixmap pix = loadSvg(filename, color);
+    iconLabel->setFixedSize(pix.size());
     iconLabel->setPixmap(pix);
 }
 
@@ -110,7 +101,7 @@ void LeftWidgetItem::setSelected(bool selected){
     if (selected) {
         widget->setStyleSheet("QWidget{background: #3D6BE5; border-radius: 4px;}");
     } else {
-        widget->setStyleSheet("QWidget{background: palette(base);}");
+        widget->setStyleSheet("QListWidget::Item:hover{background:#FF3D6BE5;border-radius: 4px;}");
     }
 }
 
